//Script was taken from NoQ's Ultimate Scavengers Mod, and modified by Shadow Wolf TJC

var MIN_ATTACKERS = 12;
var MIN_NEXUS = 4;
var MAX_SENSORS; // initialized at game start
var MAX_DEFENDERS = 8;
var MAX_GLOBAL_DEFENDERS = 25;

// unit limit constant
function atLimits() {
	return enumDroid(me).length>=130;
}

// random integer between 0 and max-1 (for convenience)
function random(max) {
	if (max<=0)
		return 0;
	return Math.floor(Math.random() * max);
}

const derrick = "A0ResourceExtractor";
const factory = "A0BaBaFactory";
const vtolfac = "A0BaBaVtolFactory";
const gen = "A0BaBaPowerGenerator";
const oilres = "OilResource";
const repair = "ScavRepairCentre";

const defenses = [
	"A0BaBaBunker",
	"A0BaBaBunker",
	"A0BaBaBunker",
	"A0CannonTower",
	"A0CannonTower",
	"A0CannonTower",
	"A0BaBaFlameTower",
	"A0BaBaFlameTower",
	"A0BaBaRocketPit",
	"A0BaBaRocketPit",
	"A0BaBaRocketPitAT",
	"A0BaBaMortarPit",
	"bbaatow",
];

const templates = [
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BaBaMG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B1BaBaPerson01","BaBaLegs","BabaRPG"],
	["B4body-sml-trike01","BaBaProp","bTrikeMG"],
	["B4body-sml-trike01","BaBaProp","bTrikeMG"],
	["B3body-sml-buggy01","BaBaProp","BuggyMG"],
	["B3body-sml-buggy01","BaBaProp","BuggyMG"],
	["B2JeepBody","BaBaProp","BJeepMG"],
	["B2JeepBody","BaBaProp","BJeepMG"],
	["B3bodyRKbuggy01","BaBaProp","BabaRocket"],
	["B3bodyRKbuggy01","BaBaProp","BabaRocket"],
	["B2RKJeepBody","BaBaProp","BabaRocket"],
	["B2RKJeepBody","BaBaProp","BabaRocket"],
	["BusBody","BaBaWheel","BusCannon"],
	["BusBody","BaBaWheel","BusCannon"],
	["BusBody","BaBaWheel","BabaPitRocketAT"],
	["BusBody","BaBaWheel","Cannon-TankDestLgt"],
	["B2tractor","BaBaHTrack","BabaFlame"],
	["B2tractor","BaBaHTrack","BabaFlame"],
	["FireBody","BaBaWheel","BabaFlame"],
	["FireBody","BaBaWheel","BabaFlame"],
	["FireBody","BaBaWheel","BusCannon"],
	["FireBody","BaBaWheel","Cannon-TankDestLgt"],
	["FireBody","BaBaWheel","BabaPitRocket"],
	["FireBody","BaBaWheel","BabaPitRocketAT"],
	["ScavCamperBody","BaBaWheel","BabaPitRocket"],
	["ScavCamperBody","BaBaWheel","BusCannon"],
	["ScavTruckBody","BaBaWheel","BabaFlame","BabaRocket","BabaPitRocketAT"],
	["ScavTruckBody","BaBaWheel","BusCannon","BabaPitRocket","BabaRocket"],
	["ScavIcevanBody","BaBaWheel","BabaFlame"],
	["ScavIcevanBody","BaBaWheel","Cannon-TankDestLgt"],
	["ScavNEXUStrack","BaBaTrack","BusCannon"],
	["ScavNEXUStrack","BaBaTrack","BusCannon"],
	["ScavNEXUStrack","BaBaTrack","BabaFlame"],
	["ScavNEXUStrack","BaBaTrack","BabaRocket"],
	["ScavNEXUStrack","BaBaTrack","BabaPitRocket"],
	["ScavNEXUStrack","BaBaTrack","BabaPitRocket"],
	["ScavNEXUStrack","BaBaTrack","BabaPitRocketAT"],
	["ScavNEXUStrack","BaBaTrack","Cannon-TankDestLgt"],
	["ScavNEXUStrack","BaBaTrack","ScavNEXUSlink"],
	["ScavNEXUStrack","BaBaTrack","ScavNEXUSlink"],
	["ScavNEXUStrack","BaBaTrack","ScavNEXUSlink"],
];

const vtolTemplates = [
	["ScavengerChopper","BaBaVtol","MG1-VTOL","MG1-VTOL","MG1-VTOL"],
	["ScavengerChopper","BaBaVtol","MG1-VTOL","MG1-VTOL","MG1-VTOL"],
	["HeavyChopper","BaBaVtol","Rocket-VTOL-Pod"],
];

// scav groups
var globalDefendGroup; // tanks that defend all bases
var needToPickGroup; // a group

var baseInfo=[];

function constructBaseInfo(x,y) {
	this.x = x;
	this.y = y;
	this.defendGroup = newGroup(); // tanks to defend the base
	this.nexusGroup = newGroup(); // tanks to capture the enemy
	this.builderGroup = newGroup(); // trucks to build base structures and defenses
	this.attackGroup = newGroup(); // tanks to attack nearby things
}

function findNearestBase(x,y) {
	var minDist=Infinity, minIdx=0;
	for (var i=0; i<baseInfo.length; ++i) {
		var d=distBetweenTwoPoints(baseInfo[i].x,baseInfo[i].y,x,y);
		if (d<minDist) {
			minDist=d;
			minIdx=i;
		}
	}
	return minIdx;
}

function findNearestRepair(x,y) {
	var list=enumStruct(me,repair);
	var minDist=Infinity,minIdx;
	for (var i=0; i<list.length; ++i) {
		var rep=list[i];
		if (rep.status==BUILT) {
			var dist=distBetweenTwoPoints(rep.x,rep.y,x,y);
			if (dist<minDist) {
				minDist=dist;
				minIdx=i;
			}
		}
	}
	return list[minIdx];
}

function factoriesOfBase(base) {
	var list=enumStruct(me,factory);
	for (var i=0; i<list.length; ++i)
		if (findNearestBase(list[i].x,list[i].y)!=base)
			list.splice(i);
	return list;
}

function reviseGroups() {
	var list=enumGroup(needToPickGroup);
	for (var i=0; i<list.length; ++i) {
		var droid=list[i];
		addDroidToSomeGroup(droid);
		// anti-stuck-at-base algorithm
		// couldn't have done it eventDroidBuilt, cause it gets overwritten 
		var x=droid.x+random(15)-7;
		if (x<2) x=2;
		if (x>=mapWidth-2) x=mapWidth-3;
		var y=droid.y+random(15)-7;
		if (y<2) y=2;
		if (y>=mapHeight-2) y=mapHeight-3;
		orderDroidLoc(droid,DORDER_MOVE,x,y); 
	}
}

function addDroidToSomeGroup(droid) {
	var base=findNearestBase(droid.x,droid.y);
	switch(droid.droidType) {
		case DROID_CONSTRUCT:
			groupAddDroid(baseInfo[base].builderGroup, droid);
			break;
		case DROID_WEAPON:
		case DROID_PERSON:
			if (droid.name.indexOf("Nexus")>-1) {
				groupAddDroid(baseInfo[base].nexusGroup, droid); 
				return;
			}
			var i = random(5);
			switch(i) {
			case 0: 
				if (groupSize(globalDefendGroup)<MAX_GLOBAL_DEFENDERS) {
					groupAddDroid(globalDefendGroup, droid); 
					return;
				}
			case 1: 
				if (groupSize(baseInfo[base].defendGroup)<MAX_DEFENDERS) {
					groupAddDroid(baseInfo[base].defendGroup, droid); 
					return;
				}
			default: 
				groupAddDroid(baseInfo[base].attackGroup, droid); break;
			}
			return;
		case DROID_SENSOR: 
			groupAddDroid(baseInfo[base].attackGroup, droid); 
			return;
	}
}

function groupOfTank(droid) {
	for (var i=0; i<baseInfo.length; ++i) {
		if (droid.group == baseInfo[i].attackGroup)
			return baseInfo[i].attackGroup;
		if (droid.group == baseInfo[i].nexusGroup)
			return baseInfo[i].nexusGroup;
	}
}

function buildStructure(droid,stat) {
	if (droid.order == DORDER_BUILD)
		return false;
	if (!isStructureAvailable(stat,me))
		return false;
	var loc = pickStructLocation(droid, stat, droid.x, droid.y, 0);
	if (typeof(loc)=="undefined")
		return false;
	orderDroidBuild(droid, DORDER_BUILD, stat, loc.x, loc.y); 
	return true;
}

function buildTower(droid) {
	return buildStructure(droid,defenses[random(defenses.length)]);
}

function establishBase(droid) {
	if (buildStructure(droid,factory)) {
		var n=baseInfo.length;
		baseInfo[n]=new constructBaseInfo(droid.x,droid.y);
		groupAddDroid(baseInfo[n].builderGroup,droid);
		return true;
	}
	return false;
}

function buildThingsWithDroid(droid) {
	if (checkAndRepair(droid))
		return;
	var factoryCount=enumStruct(me,factory).length;
	var vtolCount=enumStruct(me,vtolfac).length;
	var genCount=enumStruct(me,gen).length;
	var derrickCount=enumStruct(me,derrick).length;
	switch(random(6)) {
	case 0:
		if (!atLimits() && isStructureAvailable(factory,me) && (5*factoryCount < derrickCount || playerPower(me)>1000)) {
			establishBase(droid);
			break;
		}
	case 1:
		if (isStructureAvailable(gen,me) && derrickCount - 4*genCount>0) {
			buildStructure(droid,gen);
			break;
		}
	case 2:
		if (isStructureAvailable(vtolfac,me) && 4*vtolCount < factoryCount && gameTime>900000 ) {
			buildStructure(droid,vtolfac);
			break;
		}
	case 3:
		if (isStructureAvailable(derrick,me) && random(2)==0 && gameTime > 90000) {
			var list=enumFeature(-1, oilres);
			var minDist=Infinity,minIdx;
			for (var i=0; i<list.length; ++i) {
				var dist=distBetweenTwoPoints(droid.x,droid.y,list[i].x,list[i].y);
				if (dist<minDist) {
					minDist=dist;
					minIdx=i;
				}
			}
			if (typeof(minIdx)!="undefined") {
				orderDroidBuild(droid,DORDER_BUILD,derrick,list[minIdx].x,list[minIdx].y);
				break;
			}
		}
	case 4:
		if (isStructureAvailable(repair,me) && enumStruct(me,repair)<5) {
			var nearest=findNearestRepair(droid.x,droid.y);
			if (typeof(nearest)=="undefined" || distBetweenTwoPoints(nearest.x,nearest.y,droid.x,droid.y)>10) {
				buildStructure(droid,repair);
				break;
			}
		}
	default:
		if (playerPower(me)>300) {
			buildTower(droid);
			break;
		}
	}
}

function buildThings() {
	var list=enumDroid(me,DROID_CONSTRUCT);
	for (var i=0; i<list.length; ++i) {
		var droid=list[i];
		if (droid.order!=DORDER_BUILD) {
			buildThingsWithDroid(droid);
		}
	}
}

function produceCrane(fac) {
	if (enumDroid(me,DROID_CONSTRUCT).length > 13)
		return false;
	if (random(2)==1)
		return buildDroid(fac, "Crane", "B2crane1", "BaBaTrack", "", DROID_CONSTRUCT, "scavCrane1"); 
	else
		return buildDroid(fac, "Crane", "B2crane2", "BaBaTrack", "", DROID_CONSTRUCT, "scavCrane2"); 
}

function produceDroid(fac) {
	if (gameTime < 180000) {
		produceCrane(fac);
		return;
	}
	else	{
		var i=random(10);
		switch(i) {
			case 0: 
				if (enumDroid(me,DROID_SENSOR).length < MAX_SENSORS) {
					buildDroid(fac, "Sensor", "BusBody", "BaBaWheel", "", DROID_SENSOR, "ScavSensor"); 
					break;
				}
			case 1:
				if (produceCrane(fac))
					break;
			default: 
				var j=random(templates.length);
				if (templates[j][1]=="BaBaLegs") {
					var type=DROID_PERSON;
					var name="Scavenger";
				}
				else {
					var type=DROID_WEAPON;
					var name="Tank";
					if (templates[j][2].indexOf("NEXUS")>-1)
						name="Nexus Tank";
				}
				if (typeof(templates[j][4])!="undefined")
					buildDroid(fac, name, templates[j][0], templates[j][1], "", type, templates[j][2], templates[j][3], templates[j][4]); 
				else if (typeof(templates[j][3])!="undefined")
					buildDroid(fac, name, templates[j][0], templates[j][1], "", type, templates[j][2], templates[j][3]); 
				else
					buildDroid(fac, name, templates[j][0], templates[j][1], "", type, templates[j][2]); 
				break;
			}
	}
}

function produceVtol(fac) {
	if (gameTime > 900000)	{
		var j=random(vtolTemplates.length);
		name="Scavenger VTOL";
		if (typeof(vtolTemplates[j][4])!="undefined")
			return buildDroid(fac, name, vtolTemplates[j][0], vtolTemplates[j][1], "", DROID_TRANSPORTER, vtolTemplates[j][2], vtolTemplates[j][3], vtolTemplates[j][4]); 
		else if (typeof(vtolTemplates[j][3])!="undefined")
			return buildDroid(fac, name, vtolTemplates[j][0], vtolTemplates[j][1], "", DROID_TRANSPORTER, vtolTemplates[j][2], vtolTemplates[j][3]); 
		else
			return buildDroid(fac, name, vtolTemplates[j][0], vtolTemplates[j][1], "", DROID_TRANSPORTER, vtolTemplates[j][2]); 
	}
}

function structureReady(struct) {
	return structureIdle(struct) && (struct.status == BUILT);
}

function produceThings() {
	var list=enumStruct(me,factory);
	for (var i=0; i<list.length; ++i) {
		var fac=list[i];
		if (structureReady(fac))
			produceDroid(fac);
	}
	list=enumStruct(me,vtolfac);
	for (var i=0; i<list.length; ++i) {
		var fac=list[i];
		if (structureReady(fac))
			produceVtol(fac);
	}
}

function findNearestTarget(x,y) {
	var minDist=Infinity, minTarget;
	for (var i=0; i<maxPlayers; ++i) {
		var list;
		list=enumStruct(i);
		for (var j=0; j<list.length; ++j) {
			var d=distBetweenTwoPoints(list[j].x,list[j].y,x,y);
			if (d<minDist) {
				minDist=d;
				minTarget=list[j];
			}
		}
	}
	return minTarget;
}

function checkAndRepair(droid) {
	if (droid.order==DORDER_BUILD)
		return false;
	if (droid.health < 80) {
		var rep=findNearestRepair(droid.x,droid.y);
		if (typeof(rep)!="undefined") {
			var dist=distBetweenTwoPoints(rep.x,rep.y,droid.x,droid.y);
			if (droid.health < 60 || dist < 2) {
				if (dist>1 || droid.droidType!=DROID_TRANSPORTER) 
					orderDroidLoc(droid,DORDER_MOVE,rep.x,rep.y);
				return true;
			}
		}
	}
	return false;
}

function checkAndRepairAll() {
	var repairs=enumStruct(me,repair);
	if (repairs.length==0)
		return;
	var list=enumDroid(me);
	if (list.length==0)
		return;
	for (var j=0; j<12; ++j) {
		droid=list[random(list.length)];
		if (droid.health >= 80) 
			continue;
		var minDist=Infinity,minIdx;
		for (var i=0; i<repairs.length; ++i) if (repairs[i].status==BUILT) {
			var dist=distBetweenTwoPoints(repairs[i].x,repairs[i].y,droid.x,droid.y);
			if (dist<minDist) {
				minDist=dist;
				minIdx=i;
			}
		}
		var rep=repairs[minIdx];
		if (typeof(rep)!="undefined") {
			if (droid.health >= 60 && distBetweenTwoPoints(rep.x,rep.y,droid.x,droid.y)>=2)
				continue;
			orderDroidLoc(droid,DORDER_MOVE,rep.x,rep.y);
		}
	}
}

function attackWithDroid(droid,target,force) {
	if (checkAndRepair(droid))
		return;
	if (typeof(DORDER_OBSERVE)=="undefined")
		var DORDER_OBSERVE = 9; // HACK: waiting until this constant is exported to scripts ...
	if (droid.droidType == DROID_WEAPON || droid.droidType == DROID_PERSON)
		if (droid.order != DORDER_ATTACK || force)
			orderDroidLoc(droid,DORDER_SCOUT,target.x+random(5)-2,target.y+random(5)-2);
	else // sensor
		if (droid.order != DORDER_OBSERVE || force)
			orderDroidObj(droid,DORDER_OBSERVE,target);	
}

function attackStuff() {
	if (gameTime < 300000) //Players need time to build defenses.
		return;
	for (var j=0; j<baseInfo.length; ++j) {
		var list=enumGroup(baseInfo[j].attackGroup);
		if (list.length < MIN_ATTACKERS && !atLimits())
			continue;
		var target=findNearestTarget(baseInfo[j].x,baseInfo[j].y);
		if (typeof(target)=="undefined") 
			return;
		for (var i=0; i<list.length; ++i)
			attackWithDroid(list[i],target,false);
	}
	for (var j=0; j<baseInfo.length; ++j) {
		var list=enumGroup(baseInfo[j].nexusGroup);
		if (list.length < MIN_NEXUS && !atLimits())
			continue;
		var target=findNearestTarget(baseInfo[j].x,baseInfo[j].y);
		if (typeof(target)=="undefined") 
			return;
		for (var i=0; i<list.length; ++i)
			attackWithDroid(list[i],target,true);
	}
	var list=enumDroid(me,DROID_TRANSPORTER);
	for (var i=0; i<list.length; ++i) {
		var droid=list[i];
		if (checkAndRepair(droid))
			continue;
		var target=findNearestTarget(droid.x,droid.y);
		if (typeof(target)=="undefined") {
			// never land on the ground anyway, to hide broken rotor animation
			orderDroidLoc(droid,DORDER_MOVE,droid.x+random(5)-2,droid.y+random(5)-2); 
		} else {
			orderDroidLoc(droid,DORDER_MOVE,target.x+random(5)-2,target.y+random(5)-2);
		}
	}
}

function eventAttacked(victim, attacker) {
	if (attacker.player==me) // don't quarrel because of friendly splash damage
		return;
	if (victim.type==STRUCTURE) {
		var base=findNearestBase(victim.x,victim.y);
		var list=enumGroup(baseInfo[base].defendGroup);
		list = list.concat(enumGroup(globalDefendGroup));
		for (var i=0; i<list.length; ++i)
			attackWithDroid(list[i],attacker,true);
	} else if (victim.type==DROID_WEAPON || victim.type==DROID_PERSON) {
		if (!checkAndRepair(victim)) {
			if (victim.droidType == DROID_TRANSPORTER) {
				orderDroidObj(victim,DORDER_ATTACK,attacker);
				return;
			}
		}
		var gr=groupOfTank(victim);
		if (typeof(gr)=="undefined") 
			return;
		var list=enumGroup(gr);
		for (var i=0; i<list.length; ++i)
			if (list[i].id != victim.id)
				attackWithDroid(list[i],attacker,true);
	}
}

function eventDroidBuilt(droid, fac) {
	if (!isVTOL(droid) && droid.droidType!=DROID_TRANSPORTER)
		groupAddDroid(needToPickGroup,droid);
	queue("reviseGroups",200);
	queue("produceThings");
}

function eventStructureBuilt(structure, droid) {
	if (structure.stattype == FACTORY) {
		if (!produceCrane(structure))
			produceDroid(structure);
	} else if (structure.stattype == VTOL_FACTORY)
		produceVtol(structure);
		
}

function eventGameInit() {
	for (var i=0; i<templates.length; ++i) {
		makeComponentAvailable(templates[i][0], me);
		makeComponentAvailable(templates[i][1], me);
		if (typeof(templates[i][2])!="undefined")
			makeComponentAvailable(templates[i][2], me);
		if (typeof(templates[i][3])!="undefined")
			makeComponentAvailable(templates[i][3], me);
	}
	for (var i=0; i<vtolTemplates.length; ++i) {
		makeComponentAvailable(vtolTemplates[i][0], me);
		makeComponentAvailable(vtolTemplates[i][1], me);
		if (typeof(vtolTemplates[i][2])!="undefined")
			makeComponentAvailable(vtolTemplates[i][2], me);
		if (typeof(vtolTemplates[i][3])!="undefined")
			makeComponentAvailable(vtolTemplates[i][3], me);
	}
	makeComponentAvailable("B2crane1", me);
	makeComponentAvailable("scavCrane1", me);
	makeComponentAvailable("B2crane2", me);
	makeComponentAvailable("scavCrane2", me);
	makeComponentAvailable("ScavSensor", me);
	makeComponentAvailable("BaBaProp", me);
	makeComponentAvailable("BaBaLegs", me);
	makeComponentAvailable("BaBaWheel", me);
	makeComponentAvailable("BaBaHTrack", me);
	makeComponentAvailable("BaBaTrack", me);
	makeComponentAvailable("BaBaVtol", me);

	makeComponentAvailable("B1BaBaPerson01", me);	// enable extra components
	makeComponentAvailable("B4body-sml-trike01", me);
	makeComponentAvailable("B3body-sml-buggy01", me);
	makeComponentAvailable("B2JeepBody", me);
	makeComponentAvailable("B3bodyRKbuggy01", me);
	makeComponentAvailable("B2RKJeepBody", me);
	makeComponentAvailable("BusBody", me);
	makeComponentAvailable("FireBody", me);
	makeComponentAvailable("B2tractor", me);
	makeComponentAvailable("ScavCamperBody", me);
	makeComponentAvailable("ScavTruckBody", me);
	makeComponentAvailable("ScavIcevanBody", me);
	makeComponentAvailable("ScavNEXUStrack", me);
	makeComponentAvailable("BaBaLegs", me);
	makeComponentAvailable("BaBaProp", me);
	makeComponentAvailable("BaBaMG", me);
	makeComponentAvailable("BabaRPG", me);
	makeComponentAvailable("bTrikeMG", me);
	makeComponentAvailable("BuggyMG", me);
	makeComponentAvailable("BJeepMG", me);
	makeComponentAvailable("BabaRocket", me);
	makeComponentAvailable("BusCannon", me);
	makeComponentAvailable("BabaPitRocket", me);
	makeComponentAvailable("BabaPitRocketAT", me);
	makeComponentAvailable("Cannon-TankDestLgt", me);
	makeComponentAvailable("BabaFlame", me);
	makeComponentAvailable("ScavNEXUSlink", me);
	enableStructure(factory,me);
	enableStructure(vtolfac,me);
	enableStructure(derrick,me);
	enableStructure(gen,me);
	enableStructure(repair,me);
	//completeResearch("R-NEXUS-Immunity",me); //This should make the Scavengers immune to NEXUS absorption.
	for (var i=0; i<defenses.length; ++i)
		enableStructure(defenses[i],me);
}

// respond correctly on unit transfers
function eventObjectTransfer(object, from) {
	if (object.type == DROID) {
		eventDroidBuilt(object,null);
	} else {
		eventStructureBuilt(object,null);
	}
}

function eventStartLevel() {
	var list=enumStruct(me,factory);
	for (var i=0; i<list.length; ++i) {
		var fac=list[i];
		baseInfo[i]=new constructBaseInfo(fac.x,fac.y);
	}
	MAX_SENSORS=baseInfo.length;
	list=enumDroid(me);
	for (var i=0; i<list.length; ++i)
		addDroidToSomeGroup(list[i]);
	globalDefendGroup = newGroup();
	needToPickGroup = newGroup();
	setTimer("attackStuff", 3000);
	setTimer("buildThings", 5000);
	produceThings();
	setTimer("produceThings", 10000);
	setTimer("checkAndRepairAll",3000);
}

