
/*
 * This file describes standard stats and strategies of
 * the base (modded) game.
 *
 * If you want to make an AI specially designed for your mod, start by
 * making a copy of this file and modifying it according to your mod's rules.
 *
 * Then provide a personality to use the ruleset, similar to
 * how nb_generic.[js|ai] is provided for this ruleset.
 *
 * You may find some useful functions for working with these stats
 * in stats.js .
 *
 */

// a factor for figuring out how large things are in this ruleset,
// or simply a typical radius of a player's base
const baseScale = 20;

// diameter of laser satellite splash/incendiary damage
// for use in lassat.js
const lassatSplash = 4;

// set this to 1 to choose templates randomly, instead of later=>better.
const randomTemplates = 0;

// this function is used for avoiding AI cheats that appear due to
// being able to build droids before designing them
function iCanDesign() {
	if (difficulty === INSANE) // won't make INSANE much worse ...
		return true;
	return countFinishedStructList(structures.hqs) > 0;
}

const structures = {
	factories: [ "A0LightFactory", ],
	templateFactories: [ "A0CyborgFactory", ],
	vtolFactories: [ "A0VTolFactory1", ],
	labs: [ "A0ResearchFacility", ],
	gens: [ "A0PowerGenerator", ],
	hqs: [ "A0CommandCentre", ],
	vtolPads: [ "A0VtolPad", ],
	derricks: [ "A0ResourceExtractor", ],
	extras: [ "A0RepairCentre", "A0RepairCentre2", "A0RepairCentre3", "A0RepairCentre4", "A0Sat-linkCentre", "A0LasSatCommand", ],
	sensors: [ "Sys-SensoTower02", "Sys-CB-Tower01", "Sys-CB-Tower02", "Sys-RadarDetector01", "Sys-RadarDetector02", "Sys-SensoTowerWS", ],
};

const oilResources = [ "OilResource", ];

const powerUps = [ "OilDrum", "Crate" ];

// NOTE: you cannot use specific stats as bases, but only stattypes
// probably better make use of .name rather than of .stattype here?
const modules = [
	{ base: POWER_GEN, module: "A0PowMod1", count: 1, cost: MODULECOST.CHEAP },
	{ base: FACTORY, module: "A0FacMod1", count: 2, cost: MODULECOST.EXPENSIVE },
	{ base: VTOL_FACTORY, module: "A0FacMod1", count: 2, cost: MODULECOST.EXPENSIVE },
	{ base: RESEARCH_LAB, module: "A0ResearchModule1", count: 1, cost: MODULECOST.EXPENSIVE },
];

const targets = []
	.concat(structures.factories)
	.concat(structures.templateFactories)
	.concat(structures.vtolFactories)
	.concat(structures.extras)
;

const miscTargets = []
	.concat(structures.derricks)
;

const sensorTurrets = [
	"SensorTurret1Mk1", // sensor
	"Sensor-WideSpec", // wide spectrum sensor
];

const fundamentalResearch = [
	"R-Vehicle-Body05",
	"R-Sys-Sensor-Tower01",
	"R-Struc-Research-Module",
	"R-Struc-Factory-Module",
	"R-Struc-RepairFacility2",
	"R-Vehicle-Body11",
	"R-Struc-Power-Upgrade01",
	"R-Sys-Sensor-Tower02",
	"R-Struc-Factory-Cyborg",
	"R-Vehicle-Prop-Tracks",
	"R-Sys-CBSensor-Tower01",
	"R-Vehicle-Body12",
	"R-Sys-Autorepair-General",
	"R-Struc-Power-Upgrade03",
	"R-Struc-VTOLPad",
	"R-Struc-VTOLFactory",
	"R-Struc-Power-Upgrade06",
	"R-Vehicle-Body09",
	"R-Vehicle-Body18",
	"R-Struc-RepairFacility3",
	"R-Sys-Sensor-WSTower",
	"R-Sys-Sensor-UpLink",
	"R-Vehicle-Body10",
	"R-Vehicle-Body22",
	"R-Struc-RepairFacility4",
	"R-Wpn-LasSat",
	"R-Struc-Research-Upgrade09",
	"R-Vehicle-Body14",
	"R-Struc-Power-Upgrade09",
];

const fastestResearch = [
	"R-Struc-Research-Upgrade09",
];

// body and propulsion arrays don't affect fixed template droids
const bodyStats = [
	{ res: "R-Vehicle-Body01", stat: "Body1REC", weight: WEIGHT.LIGHT, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // viper
	{ res: "R-Vehicle-Body05", stat: "Body5REC", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // cobra
	{ res: "R-Vehicle-Body11", stat: "Body11ABT", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.KINETIC }, // python
	{ res: "R-Vehicle-Body23", stat: "Body23SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.KINETIC }, // couatl
	{ res: "R-Vehicle-Body02", stat: "Body2SUP", weight: WEIGHT.LIGHT, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // leopard
	{ res: "R-Vehicle-Body06", stat: "Body6SUPP", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // panther
	{ res: "R-Vehicle-Body09", stat: "Body9REC", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.KINETIC }, // tiger
	{ res: "R-Vehicle-Body25", stat: "Body25SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.KINETIC }, // sabretooth
	{ res: "R-Vehicle-Body20", stat: "Body20LGT", weight: WEIGHT.LIGHT, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // gladius
	{ res: "R-Vehicle-Body21", stat: "Body21MED", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // longsword
	{ res: "R-Vehicle-Body22", stat: "Body22HVY", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.KINETIC }, // claymore
	{ res: "R-Vehicle-Body27", stat: "Body27SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.KINETIC }, // excalibur
	{ res: "R-Vehicle-Body15", stat: "Body15LGT", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // wyrmling
	{ res: "R-Vehicle-Body16", stat: "Body16MED", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.KINETIC }, // salamander
	{ res: "R-Vehicle-Body13", stat: "Body13SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.KINETIC }, // wyvern
	{ res: "R-Vehicle-Body14", stat: "Body14SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.KINETIC }, // dragon
	{ res: "R-Vehicle-Body04", stat: "Body4ABT", weight: WEIGHT.LIGHT, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // bug
	{ res: "R-Vehicle-Body08", stat: "Body8MBT", weight: WEIGHT.HEAVY, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // scorpion
	{ res: "R-Vehicle-Body12", stat: "Body12SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.THERMAL }, // mantis
	{ res: "R-Vehicle-Body24", stat: "Body24SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.THERMAL }, // abaddon
	{ res: "R-Vehicle-Body17", stat: "Body17LGT", weight: WEIGHT.LIGHT, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // falcon
	{ res: "R-Vehicle-Body18", stat: "Body18MED", weight: WEIGHT.HEAVY, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // warhawk
	{ res: "R-Vehicle-Body19", stat: "Body19HVY", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.THERMAL }, // eagle
	{ res: "R-Vehicle-Body26", stat: "Body26SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.THERMAL }, // phoenix
	{ res: "R-Vehicle-Body03", stat: "Body3MBT", weight: WEIGHT.MEDIUM, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // retaliation
	{ res: "R-Vehicle-Body07", stat: "Body7ABT", weight: WEIGHT.HEAVY, usage: BODYUSAGE.UNIVERSAL, armor: BODYCLASS.THERMAL }, // retribution
	{ res: "R-Vehicle-Body10", stat: "Body10MBT", weight: WEIGHT.HEAVY, usage: BODYUSAGE.COMBAT, armor: BODYCLASS.THERMAL }, // vengeance
	{ res: "R-Vehicle-Body28", stat: "Body28SUP", weight: WEIGHT.HEAVY, usage: BODYUSAGE.GROUND, armor: BODYCLASS.THERMAL }, // nemesis
];

const classResearch = {
	kinetic: [
		[ // OBJTYPE.TANK
			"R-Vehicle-Metals09",
			"R-Vehicle-Armor-Kinetic09",
		],
		[ // OBJTYPE.BORG
			"R-Cyborg-Metals09",
			"R-Vehicle-Armor-Kinetic09",
		],
		[ // OBJTYPE.DEFS
			"R-Struc-Materials03",
			"R-Struc-Materials06",
			"R-Struc-Materials09",
		],
		[ // OBJTYPE.VTOL
			"R-Vehicle-Metals09",
			"R-Vehicle-Armor-Kinetic09",
		],
	],
	thermal: [
		[
			"R-Vehicle-Armor-Heat09",
		],
		[
			"R-Cyborg-Armor-Heat09",
		],
		[
			"R-Defense-WallUpgrade03",
			"R-Struc-Materials03",
			"R-Defense-WallUpgrade06",
			"R-Struc-Materials06",
			"R-Defense-WallUpgrade12",
			"R-Struc-Materials09",
		],
		[
			"R-Vehicle-Armor-Heat09",
		],
	],
}

// NOTE: Please don't put hover propulsion into the ground list, etc.!
// NOTE: Hover propulsion should be placed AFTER ground propulsion!
// Adaptation code relies on that for discovering map topology.
// Ground propulsions need to be ground only, hover propulsions shouldn't
// be able to cross cliffs, but should be able to cross seas, etc.
const propulsionStats = [
	{ res: "R-Vehicle-Prop-Wheels", stat: "wheeled01", usage: PROPULSIONUSAGE.GROUND },
	{ res: "R-Vehicle-Prop-Halftracks", stat: "HalfTrack", usage: PROPULSIONUSAGE.GROUND },
	{ res: "R-Vehicle-Prop-Tracks", stat: "tracked01", usage: PROPULSIONUSAGE.GROUND },
	{ res: "R-Vehicle-Prop-Hover", stat: "hover01", usage: PROPULSIONUSAGE.HOVER },
	{ res: "R-Vehicle-Prop-VTOL", stat: "V-Tol", usage: PROPULSIONUSAGE.VTOL },
];


const truckTurrets = [
	"Spade1Mk1",
	"Spade2Mk1",
	"Spade3Mk1",
	"Spade4Mk1",
];

const truckTemplates = [
	{ body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgSpade", ] }, // engineer
	{ body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCybSpade", ] }, // engineer
	{ body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgSpade2", ] }, // engineer
	{ body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCybSpade2", ] }, // engineer
	{ body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgSpade3", ] }, // engineer
	{ body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCybSpade3", ] }, // engineer
	{ body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgSpade4", ] }, // engineer
	{ body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCybSpade4", ] }, // engineer
];

const fallbackWeapon = 'machineguns';

// Unlike bodies and propulsions, weapon lines don't have any specific meaning.
// You can make as many weapon lines as you want for your ruleset.
const weaponStats = {
	machineguns: {
		// How good weapons of this path are against tanks, borgs, defenses, vtols?
		// The sum of the four should be equal to 1.
		roles: [ 0.1, 0.7, 0.1, 0.1 ],
		// This explains how are human players supposed to call this weapon path in the chat.
		chatalias: "mg",
		// This controls micromanagement of units based on the weapons of this path.
		micro: MICRO.RANGED,
		// Weapons of the path, better weapons below.
		weapons: [
			{ res: "R-Wpn-MG1Mk1", stat: "MG1Mk1", weight: WEIGHT.ULTRALIGHT }, // mg
			{ res: "R-Wpn-MG2Mk1", stat: "MG2Mk1", weight: WEIGHT.LIGHT }, // tmg
			{ res: "R-Wpn-MG3Mk1", stat: "MG3Mk1", weight: WEIGHT.MEDIUM }, // hmg
			{ res: "R-Wpn-MG3Twin", stat: "MG3Twin", weight: WEIGHT.MEDIUM }, // thmg
			{ res: "R-Wpn-MG4", stat: "MG4ROTARYMk1", weight: WEIGHT.MEDIUM }, // ag
			{ res: "R-Wpn-MG5", stat: "MG5TWINROTARY", weight: WEIGHT.MEDIUM }, // tag
			{ res: "R-Wpn-MG3Inc", stat: "MG3Inc", weight: WEIGHT.MEDIUM }, // ihmg
			{ res: "R-Wpn-MG3IncTwin", stat: "MG3IncTwin", weight: WEIGHT.MEDIUM }, // ihmg
			{ res: "R-Wpn-MG4Inc", stat: "MG4Inc", weight: WEIGHT.MEDIUM }, // iag
			{ res: "R-Wpn-MG4IncTwin", stat: "MG4IncTwin", weight: WEIGHT.MEDIUM }, // itag
			{ res: "R-Wpn-Railgun-Gattling", stat: "Railgun-Gattling", weight: WEIGHT.MEDIUM }, // railgungattling
			{ res: "R-Wpn-Railgun-GattlingTwin", stat: "Railgun-GattlingTwin", weight: WEIGHT.MEDIUM }, // railgungattling
			{ res: "R-Wpn-Railgun-GattlingInc", stat: "Railgun-GattlingInc", weight: WEIGHT.MEDIUM }, // railgungattling
			{ res: "R-Wpn-Railgun-GattlingIncTwin", stat: "Railgun-GattlingIncTwin", weight: WEIGHT.MEDIUM }, // railgungattling
		],
		// VTOL weapons of the path, in the same order.
		vtols: [
			{ res: "R-Wpn-MG1Mk1", stat: "MG1-VTOL", weight: WEIGHT.ULTRALIGHT }, // vtol mg
			{ res: "R-Wpn-MG2Mk1", stat: "MG2-VTOL", weight: WEIGHT.ULTRALIGHT }, // vtol tmg
			{ res: "R-Wpn-MG3Mk1", stat: "MG3-VTOL", weight: WEIGHT.ULTRALIGHT }, // vtol hmg
			{ res: "R-Wpn-MG4", stat: "MG4ROTARY-VTOL", weight: WEIGHT.MEDIUM }, // vtol ag
			{ res: "R-Wpn-MG3Inc", stat: "MG3Inc-VTOL", weight: WEIGHT.MEDIUM }, // vtol ag
			{ res: "R-Wpn-MG4Inc", stat: "MG4Inc-VTOL", weight: WEIGHT.MEDIUM }, // vtol ag
			{ res: "R-Wpn-Railgun-Gattling", stat: "Railgun-Gattling-VTOL", weight: WEIGHT.MEDIUM }, // vtol ag
			{ res: "R-Wpn-Railgun-GattlingInc", stat: "Railgun-GattlingInc-VTOL", weight: WEIGHT.MEDIUM }, // vtol ag
		],
		// Defensive structures of the path, in the same order.
		// NOTE: a defensive structure is recycled whenever there are at least two structures
		// with the same role available down the list
		defenses: [
			// turtle AI needs early versatile towers, hence duplicate stat
			{ res: "R-Defense-Bunker-MG1", stat: "PillBox1", defrole: DEFROLE.STANDALONE }, // mg bunker
			{ res: "R-Defense-Bunker-MG1", stat: "PillBox1", defrole: DEFROLE.STANDALONE }, // mg bunker
			{ res: "R-Defense-Bunker-MG2", stat: "PillBox2", defrole: DEFROLE.STANDALONE }, // tmg bunker
			{ res: "R-Defense-Bunker-MG3", stat: "PillBox3", defrole: DEFROLE.STANDALONE }, // hmg bunker
			{ res: "R-Defense-Bunker-MG3Twin", stat: "Bunker-MG3Twin", defrole: DEFROLE.STANDALONE }, // thmg bunker
			{ res: "R-Defense-Bunker2-MG4", stat: "Pillbox-RotMG", defrole: DEFROLE.STANDALONE }, // ag bunker
			{ res: "R-Defense-Bunker2-MG5", stat: "Bunker2-MG5", defrole: DEFROLE.STANDALONE }, // tag bunker
			{ res: "R-Defense-Bunker-MG3Inc", stat: "Bunker-MG3Inc", defrole: DEFROLE.STANDALONE }, // ihmg bunker
			{ res: "R-Defense-Bunker-MG3IncTwin", stat: "Bunker-MG3IncTwin", defrole: DEFROLE.STANDALONE }, // ihmg bunker
			{ res: "R-Defense-Bunker3-MG4Inc", stat: "Bunker3-MG4Inc", defrole: DEFROLE.STANDALONE }, // ihmg bunker
			{ res: "R-Defense-Bunker3-MG4IncTwin", stat: "Bunker3-MG4IncTwin", defrole: DEFROLE.STANDALONE }, // ithmg bunker
			{ res: "R-Defense-Bunker3-Railgun-Gattling", stat: "Bunker3-Railgun-Gattling", defrole: DEFROLE.STANDALONE }, // gg bunker
			{ res: "R-Defense-Bunker3-Railgun-GattlingTwin", stat: "Bunker3-Railgun-GattlingTwin", defrole: DEFROLE.STANDALONE }, // tgg bunker
			{ res: "R-Defense-Bunker3-Railgun-GattlingInc", stat: "Bunker3-Railgun-GattlingInc", defrole: DEFROLE.STANDALONE }, // gg bunker
			{ res: "R-Defense-Bunker3-Railgun-GattlingIncTwin", stat: "Bunker3-Railgun-GattlingIncTwin", defrole: DEFROLE.STANDALONE }, // tgg bunker
			{ res: "R-Defense-Tower-MG1", stat: "GuardTower1", defrole: DEFROLE.STANDALONE }, // mg tower
			{ res: "R-Defense-Tower-MG1", stat: "GuardTower1", defrole: DEFROLE.STANDALONE }, // mg tower
			{ res: "R-Defense-Tower-MG2", stat: "GuardTower2", defrole: DEFROLE.STANDALONE }, // tmg tower
			{ res: "R-Defense-Tower-MG3", stat: "GuardTower3", defrole: DEFROLE.STANDALONE }, // hmg tower
			{ res: "R-Defense-Tower2-MG4", stat: "GuardTower-RotMg", defrole: DEFROLE.STANDALONE }, // ag tower
			{ res: "R-Defense-Tower-MG3Inc", stat: "Tower-MG3Inc", defrole: DEFROLE.STANDALONE }, // ihmg tower
			{ res: "R-Defense-Tower3-MG4Inc", stat: "Tower3-MG4Inc", defrole: DEFROLE.STANDALONE }, // iag tower
			{ res: "R-Defense-Tower3-Railgun-Gattling", stat: "Tower3-Railgun-Gattling", defrole: DEFROLE.STANDALONE }, // gg tower
			{ res: "R-Defense-Tower3-Railgun-GattlingInc", stat: "Tower3-Railgun-GattlingInc", defrole: DEFROLE.STANDALONE }, // igg tower
			{ res: "R-Defense-WallTower-MG3", stat: "WallTower01", defrole: DEFROLE.GATEWAY }, // hmg hardpoint
			{ res: "R-Defense-WallTower-MG3Twin", stat: "WallTower-MG3Twin", defrole: DEFROLE.GATEWAY }, // thmg hardpoint
			{ res: "R-Defense-WallTower2-MG4", stat: "Wall-RotMg", defrole: DEFROLE.GATEWAY }, // ag hardpoint
			{ res: "R-Defense-WallTower2-MG5", stat: "WallTower-TwinAssaultGun", defrole: DEFROLE.GATEWAY }, // tag hardpoint
			{ res: "R-Defense-WallTower-MG3Inc", stat: "WallTower-MG3Inc", defrole: DEFROLE.GATEWAY }, // ihmg hardpoint
			{ res: "R-Defense-WallTower-MG3IncTwin", stat: "WallTower-MG3IncTwin", defrole: DEFROLE.GATEWAY }, // tihmg hardpoint
			{ res: "R-Defense-WallTower3-MG4Inc", stat: "WallTower3-MG4Inc", defrole: DEFROLE.GATEWAY }, // iag hardpoint
			{ res: "R-Defense-WallTower3-MG4IncTwin", stat: "WallTower3-MG4IncTwin", defrole: DEFROLE.GATEWAY }, // tiag hardpoint
			{ res: "R-Defense-WallTower3-Railgun-Gattling", stat: "WallTower3-Railgun-Gattling", defrole: DEFROLE.GATEWAY }, // gg hardpoint
			{ res: "R-Defense-WallTower3-Railgun-GattlingTwin", stat: "WallTower3-Railgun-GattlingTwin", defrole: DEFROLE.GATEWAY }, // tgg hardpoint
			{ res: "R-Defense-WallTower3-Railgun-GattlingInc", stat: "WallTower3-Railgun-GattlingInc", defrole: DEFROLE.GATEWAY }, // igg hardpoint
			{ res: "R-Defense-WallTower3-Railgun-GattlingIncTwin", stat: "WallTower3-Railgun-GattlingIncTwin", defrole: DEFROLE.GATEWAY }, // igg hardpoint
			{ res: "R-Defense-Super-Machinegun", stat: "Super-MG-Fort", defrole: DEFROLE.FORTRESS }, // igg hardpoint
			{ res: "R-Defense-Super-MachinegunPlas", stat: "Super-MGPlas-Fort", defrole: DEFROLE.FORTRESS }, // igg hardpoint
			{ res: "R-Defense-Super-RailgunGattling", stat: "Super-RailgunGattling-Fort", defrole: DEFROLE.FORTRESS }, // igg hardpoint
			{ res: "R-Defense-Super-RailgunGattlingPlas", stat: "Super-RailgunGattlingPlas-Fort", defrole: DEFROLE.FORTRESS }, // igg hardpoint
		],
		// Cyborg templates, better borgs below, as usual.
		templates: [
			{ res: "R-Wpn-MG1Mk1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgChaingun", ] }, // mg cyborg
			{ res: "R-Wpn-MG4", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgRotMG", ] }, // ag cyborg
			{ res: "R-Wpn-MG3Inc", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-MG3Inc", ] }, // ag cyborg
			{ res: "R-Wpn-MG4Inc", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-MG4Inc", ] }, // ag cyborg
			{ res: "R-Wpn-Railgun-Gattling", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Railgun-Gattling", ] }, // ag cyborg
			{ res: "R-Wpn-Railgun-GattlingInc", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Railgun-GattlingInc", ] }, // ag cyborg
		],
		// Extra things to research on this path, even if they don't lead to any new stuff
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	flamers: {
		roles: [ 0.3, 0.7, 0.0, 0.0 ],
		chatalias: "fl",
		micro: MICRO.MELEE,
		weapons: [
			{ res: "R-Wpn-Flamer01Mk1", stat: "Flame1Mk1", weight: WEIGHT.LIGHT }, // flamer
			{ res: "R-Wpn-Flame1Med", stat: "Flame1Med", weight: WEIGHT.MEDIUM }, // flamer
			{ res: "R-Wpn-Flame1Hvy", stat: "Flame1Hvy", weight: WEIGHT.HEAVY }, // flamer
			{ res: "R-Wpn-Flame2", stat: "Flame2", weight: WEIGHT.LIGHT }, // thermite
			{ res: "R-Wpn-Flame2Med", stat: "Flame2Med", weight: WEIGHT.MEDIUM }, // thermite
			{ res: "R-Wpn-Flame2Hvy", stat: "Flame2Hvy", weight: WEIGHT.HEAVY }, // thermite
			{ res: "R-Wpn-Plasmite-Flamer", stat: "PlasmiteFlamer", weight: WEIGHT.LIGHT }, // plasmite
			{ res: "R-Wpn-Plasmite-FlamerMed", stat: "PlasmiteFlamerMed", weight: WEIGHT.MEDIUM }, // plasmite
			{ res: "R-Wpn-Plasmite-FlamerHvy", stat: "PlasmiteFlamerHvy", weight: WEIGHT.HEAVY }, // plasmite
			{ res: "R-Wpn-Flamer-PlasmaCannon", stat: "Flamer-PlasmaCannon", weight: WEIGHT.ULTRAHEAVY }, // plasma cannon
		],
		vtols: [],
		defenses: [
			{ res: "R-Defense-Bunker4-Flamer-PlasmaCannon", stat: "Bunker4-Flamer-PlasmaCannon", defrole: DEFROLE.STANDALONE }, // plasma cannon bunker
			{ res: "R-Defense-Empl-Flame1Mk1", stat: "Empl-Flame1Mk1", defrole: DEFROLE.GATEWAY }, // lgt flamer bunker
			{ res: "R-Defense-Empl-Flame1Med", stat: "Empl-Flame1Med", defrole: DEFROLE.GATEWAY }, // med flamer bunker
			{ res: "R-Defense-Empl-Flame1Hvy", stat: "Empl-Flame1Hvy", defrole: DEFROLE.GATEWAY }, // hvy flamer bunker
			{ res: "R-Defense-Empl2-Flame2", stat: "Empl2-Flame2", defrole: DEFROLE.GATEWAY }, // lgt thermite bunker
			{ res: "R-Defense-Empl2-Flame2Med", stat: "Empl2-Flame2Med", defrole: DEFROLE.GATEWAY }, // med thermite bunker
			{ res: "R-Defense-Empl2-Flame2Hvy", stat: "Empl2-Flame2Hvy", defrole: DEFROLE.GATEWAY }, // hvy thermite bunker
			{ res: "R-Defense-Empl3-PlasmiteFlamer", stat: "Empl3-PlasmiteFlamer", defrole: DEFROLE.GATEWAY }, // lgt plasmite bunker
			{ res: "R-Defense-Empl3-PlasmiteFlamerMed", stat: "Empl3-PlasmiteFlamerMed", defrole: DEFROLE.GATEWAY }, // med plasmite bunker
			{ res: "R-Defense-Empl3-PlasmiteFlamerHvy", stat: "Empl3-PlasmiteFlamerHvy", defrole: DEFROLE.GATEWAY }, // hvy plasmite bunker
			{ res: "R-Defense-WallTower4-Flamer-PlasmaCannon", stat: "WallTower4-Flamer-PlasmaCannon", defrole: DEFROLE.STANDALONE }, // plasma cannon bunker
			{ res: "R-Defense-Super-FlamerPlasma", stat: "Super-FlamerPlasma-Fort", defrole: DEFROLE.FORTRESS }, // plasma cannon fort
		],
		templates: [
			{ res: "R-Wpn-Flamer01Mk1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgFlamer01", ] }, // flamer cyborg
			{ res: "R-Wpn-Flamer01Mk1", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Flamer1", ] }, // flamer cyborg
			{ res: "R-Wpn-Flame2", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Thermite", ] }, // flamer cyborg
			{ res: "R-Wpn-Flame2", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Flamer2", ] }, // flamer cyborg
			{ res: "R-Wpn-Plasmite-Flamer", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Flamer3", ] }, // flamer cyborg
		],
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	cannons: {
		roles: [ 0.5, 0.2, 0.3, 0.0 ],
		chatalias: "cn",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-Cannon1Mk1", stat: "Cannon1Mk1", weight: WEIGHT.LIGHT }, // lc
			{ res: "R-Wpn-Cannon2Mk1", stat: "Cannon2A-TMk1", weight: WEIGHT.HEAVY }, // mc
			{ res: "R-Wpn-Cannon3Mk1", stat: "Cannon375mmMk1", weight: WEIGHT.ULTRAHEAVY }, // hc
			{ res: "R-Wpn-Cannon5", stat: "Cannon5VulcanMk1", weight: WEIGHT.HEAVY }, // ac
			{ res: "R-Wpn-Cannon6TwinAslt", stat: "Cannon6TwinAslt", weight: WEIGHT.ULTRAHEAVY }, // tac
			{ res: "R-Wpn-Cannon-HPVLgt", stat: "Cannon-HPVLgt", weight: WEIGHT.HEAVY }, // lgt hpv
			{ res: "R-Wpn-Cannon4AMk1", stat: "Cannon4AUTOMk1", weight: WEIGHT.HEAVY }, // med hpv
			{ res: "R-Wpn-Railgun-Proto", stat: "Railgun-Proto", weight: WEIGHT.LIGHT }, // proto rail
			{ res: "R-Wpn-Cannon-HPVHvy", stat: "Cannon-HPVHvy", weight: WEIGHT.HEAVY }, // hvy hpv
			{ res: "R-Wpn-Cannon-HPVAslt", stat: "Cannon-HPVAslt", weight: WEIGHT.HEAVY }, // aslt hpv
			{ res: "R-Wpn-Cannon-HPVTwinAslt", stat: "Cannon-HPVTwinAslt", weight: WEIGHT.HEAVY }, // twinaslt hpv
			{ res: "R-Wpn-Railgun-Proto", stat: "Railgun-Proto", weight: WEIGHT.LIGHT }, // proto rail
			{ res: "R-Wpn-RailGun01", stat: "RailGun1Mk1", weight: WEIGHT.LIGHT }, // needle
			{ res: "R-Wpn-RailGun02", stat: "RailGun2Mk1", weight: WEIGHT.HEAVY }, // rail
			{ res: "R-Wpn-RailGun03", stat: "RailGun3Mk1", weight: WEIGHT.ULTRAHEAVY }, // gauss
			{ res: "R-Wpn-Railgun-Aslt", stat: "Railgun-Aslt", weight: WEIGHT.ULTRAHEAVY }, // gauss
			{ res: "R-Wpn-Railgun-TwinAslt", stat: "Railgun-TwinAslt", weight: WEIGHT.ULTRAHEAVY }, // gauss
		],
		vtols: [
			{ res: "R-Wpn-Cannon1Mk1", stat: "Cannon1-VTOL", weight: WEIGHT.LIGHT }, // lc
			{ res: "R-Wpn-Cannon2Mk1", stat: "Cannon-Med-VTOL", weight: WEIGHT.LIGHT }, // lc
			{ res: "R-Wpn-Cannon5", stat: "Cannon5Vulcan-VTOL", weight: WEIGHT.HEAVY }, // ac
			{ res: "R-Wpn-Cannon-HPVLgt", stat: "Cannon-HPVLgt-VTOL", weight: WEIGHT.HEAVY }, // hpv
			{ res: "R-Wpn-Cannon4AMk1", stat: "Cannon4AUTO-VTOL", weight: WEIGHT.HEAVY }, // hpv
			{ res: "R-Wpn-Cannon-HPVAslt", stat: "Cannon-HPVAslt-VTOL", weight: WEIGHT.HEAVY }, // ac
			{ res: "R-Wpn-RailGun01", stat: "RailGun1-VTOL", weight: WEIGHT.LIGHT }, // needle
			{ res: "R-Wpn-RailGun02", stat: "RailGun2-VTOL", weight: WEIGHT.HEAVY }, // rail
			{ res: "R-Wpn-Railgun-Shotgun", stat: "Railgun-Shotgun-VTOL", weight: WEIGHT.LIGHT }, // needle
			{ res: "R-Wpn-Railgun-Aslt", stat: "Railgun-Aslt-VTOL", weight: WEIGHT.LIGHT }, // needle
		],
		defenses: [
			{ res: "R-Defense-Bunker-Cannon-Lgt", stat: "PillBox4", defrole: DEFROLE.STANDALONE }, // lc bunker
			{ res: "R-Defense-Bunker-Cannon-Med", stat: "Bunker-Cannon-Med", defrole: DEFROLE.STANDALONE }, // mc bunker
			{ res: "R-Defense-Bunker-Cannon-Hvy", stat: "Bunker-Cannon-Hvy", defrole: DEFROLE.STANDALONE }, // hc bunker
			{ res: "R-Defense-Bunker-Cannon-Aslt", stat: "Bunker-Cannon-Aslt", defrole: DEFROLE.STANDALONE }, // ac bunker
			{ res: "R-Defense-Bunker-Cannon-TwinAslt", stat: "PillBox-Cannon6", defrole: DEFROLE.STANDALONE }, // tac bunker
			{ res: "R-Defense-Bunker2-Cannon-HPVLgt", stat: "Bunker2-Cannon-HPVLgt", defrole: DEFROLE.STANDALONE }, // lgt hpv bunker
			{ res: "R-Defense-Bunker2-Cannon-HPVMed", stat: "Bunker2-Cannon-HPVMed", defrole: DEFROLE.STANDALONE }, // med hpv bunker
			{ res: "R-Defense-Bunker2-Cannon-HPVHvy", stat: "Bunker2-Cannon-HPVHvy", defrole: DEFROLE.STANDALONE }, // hvy hpv bunker
			{ res: "R-Defense-Bunker2-Cannon-HPVAslt", stat: "Bunker2-Cannon-HPVAslt", defrole: DEFROLE.STANDALONE }, // aslt hpv bunker
			{ res: "R-Defense-Bunker2-Cannon-HPVTwinAslt", stat: "Bunker2-Cannon-HPVTwinAslt", defrole: DEFROLE.STANDALONE }, // aslt hpv bunker
			{ res: "R-Defense-Bunker-Railgun-Proto", stat: "Bunker-Railgun-Proto", defrole: DEFROLE.STANDALONE }, // railgun proto bunker
			{ res: "R-Defense-Bunker2-Railgun-Proto", stat: "Bunker2-Railgun-Proto", defrole: DEFROLE.STANDALONE }, // railgun proto bunker
			{ res: "R-Defense-Bunker3-Railgun-Lgt", stat: "Bunker3-Railgun-Lgt", defrole: DEFROLE.STANDALONE }, // needlegun bunker
			{ res: "R-Defense-Bunker3-Railgun-Med", stat: "Bunker3-Railgun-Med", defrole: DEFROLE.STANDALONE }, // railgun bunker
			{ res: "R-Defense-Bunker3-Railgun-Hvy", stat: "Bunker3-Railgun-Hvy", defrole: DEFROLE.STANDALONE }, // gauss cannon bunker
			{ res: "R-Defense-Bunker3-Railgun-Aslt", stat: "Bunker3-Railgun-Aslt", defrole: DEFROLE.STANDALONE }, // aslt needlegun bunker
			{ res: "R-Defense-Bunker3-Railgun-TwinAslt", stat: "Bunker3-Railgun-TwinAslt", defrole: DEFROLE.STANDALONE }, // aslt needlegun bunker
			{ res: "R-Defense-Tower-Cannon-Lgt", stat: "Tower-Cannon-Lgt", defrole: DEFROLE.STANDALONE }, // lc tower
			{ res: "R-Defense-Tower-Cannon-Med", stat: "Tower-Cannon-Med", defrole: DEFROLE.STANDALONE }, // mc tower
			{ res: "R-Defense-Tower-Cannon-Aslt", stat: "Tower-Cannon-Aslt", defrole: DEFROLE.STANDALONE }, // ac tower
			{ res: "R-Defense-Tower2-Cannon-HPVLgt", stat: "Tower2-Cannon-HPVLgt", defrole: DEFROLE.STANDALONE }, // lc tower
			{ res: "R-Defense-Tower2-Cannon-HPVMed", stat: "Tower-VulcanCan", defrole: DEFROLE.STANDALONE }, // mc tower
			{ res: "R-Defense-Tower2-Cannon-HPVAslt", stat: "Tower2-Cannon-HPVAslt", defrole: DEFROLE.STANDALONE }, // ac tower
			{ res: "R-Defense-Tower3-Railgun-Lgt", stat: "GuardTower-Rail1", defrole: DEFROLE.STANDALONE }, // needlegun tower
			{ res: "R-Defense-Tower3-Railgun-Med", stat: "Tower3-Railgun-Med", defrole: DEFROLE.STANDALONE }, // railgun tower
			{ res: "R-Defense-Tower3-Railgun-Aslt", stat: "Tower3-Railgun-Aslt", defrole: DEFROLE.STANDALONE }, // aslt needlegun tower
			{ res: "R-Defense-WallTower-Cannon-Lgt", stat: "WallTower02", defrole: DEFROLE.STANDALONE }, // lc bunker
			{ res: "R-Defense-WallTower-Cannon-Med", stat: "WallTower03", defrole: DEFROLE.STANDALONE }, // mc bunker
			{ res: "R-Defense-WallTower-Cannon-Hvy", stat: "WallTower04", defrole: DEFROLE.STANDALONE }, // hc bunker
			{ res: "R-Defense-WallTower-Cannon-Aslt", stat: "Wall-VulcanCan", defrole: DEFROLE.STANDALONE }, // ac bunker
			{ res: "R-Defense-WallTower-Cannon-TwinAslt", stat: "WallTower-Cannon-TwinAslt", defrole: DEFROLE.STANDALONE }, // tac bunker
			{ res: "R-Defense-WallTower2-Cannon-HPVLgt", stat: "WallTower2-Cannon-HPVLgt", defrole: DEFROLE.STANDALONE }, // lgt hpv bunker
			{ res: "R-Defense-WallTower2-Cannon-HPVMed", stat: "WallTower-HPVcannon", defrole: DEFROLE.STANDALONE }, // med hpv bunker
			{ res: "R-Defense-WallTower2-Cannon-HPVHvy", stat: "WallTower2-Cannon-HPVHvy", defrole: DEFROLE.STANDALONE }, // hvy hpv bunker
			{ res: "R-Defense-WallTower2-Cannon-HPVAslt", stat: "WallTower2-Cannon-HPVAslt", defrole: DEFROLE.STANDALONE }, // aslt hpv bunker
			{ res: "R-Defense-WallTower2-Cannon-HPVTwinAslt", stat: "WallTower2-Cannon-HPVTwinAslt", defrole: DEFROLE.STANDALONE }, // aslt hpv bunker
			{ res: "R-Defense-WallTower-Railgun-Proto", stat: "WallTower-Railgun-Proto", defrole: DEFROLE.STANDALONE }, // railgun proto bunker
			{ res: "R-Defense-WallTower2-Railgun-Proto", stat: "WallTower2-Railgun-Proto", defrole: DEFROLE.STANDALONE }, // railgun proto bunker
			{ res: "R-Defense-WallTower3-Railgun-Lgt", stat: "WallTower3-Railgun-Lgt", defrole: DEFROLE.STANDALONE }, // needlegun bunker
			{ res: "R-Defense-WallTower3-Railgun-Med", stat: "WallTower-Rail2", defrole: DEFROLE.STANDALONE }, // railgun bunker
			{ res: "R-Defense-WallTower3-Railgun-Hvy", stat: "WallTower-Rail3", defrole: DEFROLE.STANDALONE }, // gauss cannon bunker
			{ res: "R-Defense-WallTower3-Railgun-Aslt", stat: "WallTower3-Railgun-Aslt", defrole: DEFROLE.STANDALONE }, // aslt needlegun bunker
			{ res: "R-Defense-WallTower3-Railgun-TwinAslt", stat: "WallTower3-Railgun-TwinAslt", defrole: DEFROLE.STANDALONE }, // aslt needlegun bunker
			{ res: "R-Defense-Super-Cannon", stat: "X-Super-Cannon", defrole: DEFROLE.FORTRESS }, // cannon fort
			{ res: "R-Defense-Super-RotCannon", stat: "Super-RotCannon-Fort", defrole: DEFROLE.FORTRESS }, // rot cannon fort
			{ res: "R-Defense-Super-RotRailgun", stat: "Super-Railgun-Fort", defrole: DEFROLE.FORTRESS }, // rot railgun fort
			{ res: "R-Defense-MassDriver", stat: "X-Super-MassDriver", defrole: DEFROLE.FORTRESS }, // mass driver fort
		],
		templates: [
			{ res: "R-Wpn-Cannon1Mk1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgCannon", ] }, // lc borg
			{ res: "R-Cyborg-Hvywpn-Mcannon", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-Mcannon", ] }, // mc super
			{ res: "R-Cyborg-Hvywpn-Acannon", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-Acannon", ] }, // ac super
			{ res: "R-Wpn-Cannon-HPVLgt", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Cannon-HPVLgt", ] }, // lc borg
			{ res: "R-Cyborg-Hvywpn-HPV", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-HPV", ] }, // hpv super
			{ res: "R-Wpn-Cannon-HPVAslt", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Cannon-HPVAslt", ] }, // hpv super
			{ res: "R-Wpn-RailGun01", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Rail1", ] }, // needle borg
			{ res: "R-Cyborg-Hvywpn-RailGunner", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-RailGunner", ] }, // rail super
			{ res: "R-Wpn-Railgun-Aslt", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Railgun-Aslt", ] }, // rail super
		],
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	cannons_AA: {
		roles: [ 0.0, 0.0, 0.0, 1.0 ],
		chatalias: "ca",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-AAGun02", stat: "AAGun2Mk1", weight: WEIGHT.HEAVY },
		],
		vtols: [],
		defenses: [
			{ res: "R-Defense-AASite-QuadBof", stat: "AASite-QuadBof", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower-DoubleAAgun", stat: "WallTower-DoubleAAGun", defrole: DEFROLE.GATEWAY },
		],
		templates: [],
		extras: [],
	},
	mortars: {
		roles: [ 0.2, 0.4, 0.4, 0.0 ],
		chatalias: "mo",
		micro: MICRO.DUMB,
		weapons: [
			{ res: "R-Wpn-Mortar01Lt", stat: "Mortar1Mk1", weight: WEIGHT.HEAVY }, // duplicate stat!
			{ res: "R-Wpn-Mortar02Hvy", stat: "Mortar2Mk1", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar3", stat: "Mortar3ROTARYMk1", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar-GaussInc", stat: "Mortar-GaussInc", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-MortarHvyPlas", stat: "MortarHvyPlas", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-MortarRotPlas", stat: "MortarRotPlas", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-HowitzerMk1", stat: "Howitzer105Mk1", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HvyHowitzer", stat: "Howitzer150Mk1", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Howitzer03-Rot", stat: "Howitzer03-Rot", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Howitzer-Incenediary", stat: "Howitzer-Incenediary", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerHvyPlas", stat: "HowitzerHvyPlas", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerRotPlas", stat: "HowitzerRotPlas", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Mortar-Gauss", stat: "Mortar-Gauss", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar-Gauss", stat: "Mortar-Gauss", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar-GaussHvy", stat: "Mortar-GaussHvy", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-HowitzerGauss", stat: "HowitzerGauss", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerGaussHvy", stat: "HowitzerGaussHvy", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerGaussRot", stat: "HowitzerGaussRot", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Mortar-GaussInc", stat: "Mortar-GaussInc", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar-GaussHvyPlas", stat: "Mortar-GaussHvyPlas", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Mortar-GaussRotPlas", stat: "Mortar-GaussRotPlas", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-HowitzerGaussInc", stat: "HowitzerGaussInc", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerGaussHvyPlas", stat: "HowitzerGaussHvyPlas", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-HowitzerGaussRotPlas", stat: "HowitzerGaussRotPlas", weight: WEIGHT.ULTRAHEAVY },
		],
		vtols: [
			{ res: "R-Wpn-Bomb01", stat: "Bomb1-VTOL-LtHE", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Bomb02", stat: "Bomb2-VTOL-HvHE", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Bomb03", stat: "Bomb3-VTOL-LtINC", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Bomb04", stat: "Bomb4-VTOL-HvyINC", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Bomb05", stat: "Bomb5-VTOL-Plasmite", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Bomb-FuelAir", stat: "Bomb-FuelAir", weight: WEIGHT.ULTRAHEAVY },
			{ res: "R-Wpn-Bomb-Earthquake", stat: "Bomb-Earthquake", weight: WEIGHT.ULTRAHEAVY },
		],
		defenses: [
			{ res: "R-Defense-Bunker-Mortar", stat: "Bunker-Mortar", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker-MortarHvy", stat: "Bunker-MortarHvy", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker-MortarRot", stat: "Bunker-MortarRot", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-MortarHvyPlas", stat: "Bunker3-MortarHvyPlas", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker2-Howitzer", stat: "Bunker2-Howitzer", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker2-HowitzerHvy", stat: "Bunker2-HowitzerHvy", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker2-HowitzerRot", stat: "Bunker2-HowitzerRot", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-Mortar-Gauss", stat: "Bunker4-Mortar-Gauss", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker4-Mortar-GaussHvy", stat: "Bunker4-Mortar-GaussHvy", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker4-Mortar-GaussRot", stat: "Bunker4-Mortar-GaussRot", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-HowitzerHvyPlas", stat: "Bunker3-HowitzerHvyPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker3-HowitzerRotPlas", stat: "Bunker3-HowitzerRotPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGauss", stat: "Bunker4-HowitzerGauss", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGaussHvy", stat: "Bunker4-HowitzerGaussHvy", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGaussRot", stat: "Bunker4-HowitzerGaussRot", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGaussInc", stat: "Bunker4-HowitzerGaussInc", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGaussHvyPlas", stat: "Bunker4-HowitzerGaussHvyPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Bunker4-HowitzerGaussRotPlas", stat: "Bunker4-HowitzerGaussRotPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl-Mortar", stat: "Emplacement-MortarPit01", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl-MortarHvy", stat: "Emplacement-MortarPit02", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl-MortarRot", stat: "Emplacement-RotMor", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl-MortarInc", stat: "Emplacement-MortarPit-Incenediary", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl3-MortarHvyPlas", stat: "Empl3-MortarHvyPlas", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl2-Howitzer", stat: "Emplacement-Howitzer105", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl2-HowitzerHvy", stat: "Emplacement-Howitzer150", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl2-HowitzerRot", stat: "Emplacement-RotHow", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-Mortar-Gauss", stat: "Empl4-Mortar-Gauss", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl4-Mortar-GaussHvy", stat: "Empl4-Mortar-GaussHvy", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl4-Mortar-GaussRot", stat: "Empl4-Mortar-GaussRot", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Empl2-HowitzerInc", stat: "Emplacement-Howitzer-Incenediary", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl3-HowitzerHvyPlas", stat: "Empl3-HowitzerHvyPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl3-HowitzerRotPlas", stat: "Empl3-HowitzerRotPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGauss", stat: "Empl4-HowitzerGauss", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGaussHvy", stat: "Empl4-HowitzerGaussHvy", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGaussRot", stat: "Empl4-HowitzerGaussRot", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGaussInc", stat: "Empl4-HowitzerGaussInc", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGaussHvyPlas", stat: "Empl4-HowitzerGaussHvyPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Empl4-HowitzerGaussRotPlas", stat: "Empl4-HowitzerGaussRotPlas", defrole: DEFROLE.ARTY },
			{ res: "R-Defense-Super-Mortar", stat: "Super-Mortar-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-MortarPlas", stat: "Super-MortarPlas-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-MortarGauss", stat: "Super-MortarGauss-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-MortarGaussPlas", stat: "Super-MortarGaussPlas-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-Howitzer", stat: "Super-Howitzer-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-HowitzerPlas", stat: "Super-HowitzerPlas-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-HowitzerGauss", stat: "Super-HowitzerGauss-Empl", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-HowitzerGaussPlas", stat: "Super-HowitzerGaussPlas-Empl", defrole: DEFROLE.FORTRESS },
		],
		templates: [
			{ res: "R-Wpn-Mortar01Lt", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Grenade", ] },
			{ res: "R-Wpn-Mortar-Gauss", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Mortar-Gauss", ] },
		],
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	rockets_AT: {
		roles: [ 1.0, 0.0, 0.0, 0.0 ],
		chatalias: "rx",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-Rocket05-MiniPod", stat: "Rocket-Pod", weight: WEIGHT.LIGHT }, // pod
			{ res: "R-Wpn-Rocket-PodTwin", stat: "Rocket-PodTwin", weight: WEIGHT.MEDIUM }, // pod
			{ res: "R-Wpn-Rocket-PodQuad", stat: "Rocket-PodQuad", weight: WEIGHT.HEAVY }, // pod
			{ res: "R-Wpn-Rocket01-LtAT", stat: "Rocket-LtA-T", weight: WEIGHT.LIGHT }, // lancer
			{ res: "R-Wpn-Rocket01-LtATHvy", stat: "Rocket-LtA-THvy", weight: WEIGHT.HEAVY }, // lancer
			{ res: "R-Wpn-Rocket-Pod2", stat: "Rocket-Pod2", weight: WEIGHT.LIGHT }, // pod
			{ res: "R-Wpn-Rocket-Pod2Twin", stat: "Rocket-Pod2Twin", weight: WEIGHT.MEDIUM }, // pod
			{ res: "R-Wpn-Rocket-Pod2Quad", stat: "Rocket-Pod2Quad", weight: WEIGHT.HEAVY }, // pod
			{ res: "R-Wpn-Rocket07-Tank-Killer", stat: "Rocket-HvyA-T", weight: WEIGHT.LIGHT }, // tk
			{ res: "R-Wpn-Rocket07-Tank-KillerHvy", stat: "Rocket-HvyA-THvy", weight: WEIGHT.HEAVY }, // tk
			{ res: "R-Wpn-Rocket-Pod3", stat: "Rocket-Pod3", weight: WEIGHT.LIGHT }, // pod
			{ res: "R-Wpn-Rocket-Pod3Twin", stat: "Rocket-Pod3Twin", weight: WEIGHT.MEDIUM }, // pod
			{ res: "R-Wpn-Rocket-Pod3Quad", stat: "Rocket-Pod3Quad", weight: WEIGHT.HEAVY }, // pod
			{ res: "R-Wpn-Missile2A-T", stat: "Missile-A-T", weight: WEIGHT.LIGHT }, // scourge
			{ res: "R-Wpn-Missile2A-THvy", stat: "Missile-A-THvy", weight: WEIGHT.HEAVY }, // scourge
		],
		vtols: [
			{ res: "R-Wpn-Rocket05-MiniPod", stat: "Rocket-VTOL-Pod", weight: WEIGHT.ULTRALIGHT }, // pod
			{ res: "R-Wpn-Rocket01-LtAT", stat: "Rocket-VTOL-LtA-T", weight: WEIGHT.LIGHT }, // lancer
			{ res: "R-Wpn-Rocket-Pod2", stat: "Rocket-VTOL-Pod2", weight: WEIGHT.ULTRALIGHT }, // pod
			{ res: "R-Wpn-Rocket07-Tank-Killer", stat: "Rocket-VTOL-HvyA-T", weight: WEIGHT.LIGHT }, // tk
			{ res: "R-Wpn-Rocket-Pod3", stat: "Rocket-VTOL-Pod3", weight: WEIGHT.ULTRALIGHT }, // pod
			{ res: "R-Wpn-Missile2A-T", stat: "Missile-VTOL-AT", weight: WEIGHT.LIGHT }, // scourge
		],
		defenses: [
			// rocket turtle AI needs early AT gateway towers, hence duplicate stat
			{ res: "R-Defense-Bunker-Rocket-Pod", stat: "Bunker-Rocket-Pod", defrole: DEFROLE.GATEWAY }, // pod bunker
			{ res: "R-Defense-Bunker-Rocket-Pod", stat: "Bunker-Rocket-Pod", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker-Rocket-PodTwin", stat: "Bunker-Rocket-PodTwin", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker-Rocket-PodQuad", stat: "Bunker-Rocket-PodQuad", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker-Rocket-AT", stat: "PillBox6", defrole: DEFROLE.GATEWAY }, // lancer bunker
			{ res: "R-Defense-Bunker-Rocket-ATHvy", stat: "Bunker-Rocket-ATHvy", defrole: DEFROLE.STANDALONE }, // lancer bunker
			{ res: "R-Defense-Bunker2-Rocket-Pod2", stat: "Bunker2-Rocket-Pod2", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker2-Rocket-Pod2Twin", stat: "Bunker2-Rocket-Pod2Twin", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker2-Rocket-Pod2Quad", stat: "Bunker2-Rocket-Pod2Quad", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker2-Rocket-AT2", stat: "Bunker2-Rocket-AT2", defrole: DEFROLE.STANDALONE }, // tk bunker
			{ res: "R-Defense-Bunker2-Rocket-AT2Hvy", stat: "Bunker2-Rocket-AT2Hvy", defrole: DEFROLE.STANDALONE }, // tk bunker
			{ res: "R-Defense-Bunker3-Rocket-Pod3", stat: "Bunker3-Rocket-Pod3", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker3-Rocket-Pod3Twin", stat: "Bunker3-Rocket-Pod3Twin", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker3-Rocket-Pod3Quad", stat: "Bunker3-Rocket-Pod3Quad", defrole: DEFROLE.STANDALONE }, // pod bunker
			{ res: "R-Defense-Bunker3-Rocket-AT3", stat: "Bunker3-Rocket-AT3", defrole: DEFROLE.STANDALONE }, // scourge bunker
			{ res: "R-Defense-Bunker3-Rocket-AT3Hvy", stat: "Bunker3-Rocket-AT3Hvy", defrole: DEFROLE.STANDALONE }, // scourge bunker
			{ res: "R-Defense-Tower-Rocket-Pod", stat: "GuardTower6", defrole: DEFROLE.GATEWAY }, // pod tower
			{ res: "R-Defense-Tower-Rocket-Pod", stat: "GuardTower6", defrole: DEFROLE.STANDALONE }, // pod tower
			{ res: "R-Defense-Tower-Rocket-AT", stat: "GuardTower5", defrole: DEFROLE.STANDALONE }, // lancer tower
			{ res: "R-Defense-Tower2-Rocket-Pod2", stat: "Tower2-Rocket-Pod2", defrole: DEFROLE.STANDALONE }, // pod tower
			{ res: "R-Defense-Tower2-Rocket-AT2", stat: "Tower2-Rocket-AT2", defrole: DEFROLE.STANDALONE }, // tk tower
			{ res: "R-Defense-Tower3-Rocket-Pod3", stat: "Tower3-Rocket-Pod3", defrole: DEFROLE.STANDALONE }, // pod tower
			{ res: "R-Defense-Tower3-Rocket-AT3", stat: "GuardTower-ATMiss", defrole: DEFROLE.STANDALONE }, // scourge tower
			{ res: "R-Defense-WallTower-Rocket-Pod", stat: "WallTower-Rocket-Pod", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower-Rocket-PodTwin", stat: "WallTower-Rocket-PodTwin", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower-Rocket-PodQuad", stat: "WallTower-Rocket-PodQuad", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower-Rocket-AT", stat: "WallTower06", defrole: DEFROLE.GATEWAY }, // lancer hardpoint
			{ res: "R-Defense-WallTower-Rocket-ATHvy", stat: "WallTower-Rocket-ATHvy", defrole: DEFROLE.GATEWAY }, // lancer hardpoint
			{ res: "R-Defense-WallTower2-Rocket-Pod2", stat: "WallTower2-Rocket-Pod2", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower2-Rocket-Pod2Twin", stat: "WallTower2-Rocket-Pod2Twin", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower2-Rocket-Pod2Quad", stat: "WallTower2-Rocket-Pod2Quad", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower2-Rocket-AT2", stat: "WallTower-HvATrocket", defrole: DEFROLE.GATEWAY }, // tk hardpoint
			{ res: "R-Defense-WallTower2-Rocket-AT2Hvy", stat: "WallTower2-Rocket-AT2Hvy", defrole: DEFROLE.GATEWAY }, // tk hardpoint
			{ res: "R-Defense-WallTower3-Rocket-Pod3", stat: "WallTower3-Rocket-Pod3", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower3-Rocket-Pod3Twin", stat: "WallTower3-Rocket-Pod3Twin", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower3-Rocket-Pod3Quad", stat: "WallTower3-Rocket-Pod3Quad", defrole: DEFROLE.GATEWAY }, // pod hardpoint
			{ res: "R-Defense-WallTower3-Rocket-AT3", stat: "WallTower-Atmiss", defrole: DEFROLE.GATEWAY }, // scourge hardpoint
			{ res: "R-Defense-WallTower3-Rocket-AT3Hvy", stat: "WallTower3-Rocket-AT3Hvy", defrole: DEFROLE.GATEWAY }, // scourge hardpoint
			{ res: "R-Defense-Super-Rocket", stat: "X-Super-Rocket", defrole: DEFROLE.FORTRESS }, // rocket bastion
			{ res: "R-Defense-Super-Missile", stat: "X-Super-Missile", defrole: DEFROLE.FORTRESS }, // missile fortress
		],
		templates: [
			{ res: "R-Wpn-Rocket05-MiniPod", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-Pod", ] }, // lancer borg
			{ res: "R-Wpn-Rocket01-LtAT", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "CyborgRocket", ] }, // lancer borg
			{ res: "R-Wpn-Rocket-Pod2", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-Pod2", ] }, // lancer borg
			{ res: "R-Cyborg-Hvywpn-TK", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-TK", ] }, // tk super
			{ res: "R-Wpn-Rocket-Pod3", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-Pod3", ] }, // lancer borg
			{ res: "R-Wpn-Missile2A-T", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Atmiss", ] }, // scourge borg
			{ res: "R-Cyborg-Hvywpn-A-T", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "Cyb-Hvywpn-A-T", ] }, // scourge super
		],
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	rockets_Arty: {
		roles: [ 0.2, 0.4, 0.4, 0.0 ],
		chatalias: "rxarty",
		micro: MICRO.DUMB,
		weapons: [
			{ res: "R-Wpn-Rocket02-MRL", stat: "Rocket-MRL", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket02-MRLHvy", stat: "Rocket-MRLHvy", weight: WEIGHT.HEAVY }, // mra
			{ res: "R-Wpn-Rocket-TopAttack", stat: "Rocket-TopAttack", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket-TopAttackHvy", stat: "Rocket-TopAttackHvy", weight: WEIGHT.HEAVY }, // mra
			{ res: "R-Wpn-Rocket03-HvAT", stat: "Rocket-BB", weight: WEIGHT.MEDIUM }, // bb
			{ res: "R-Wpn-Rocket-BB2", stat: "Rocket-BB2", weight: WEIGHT.MEDIUM }, // bb
			{ res: "R-Wpn-Rocket-TopAtkInc", stat: "Rocket-TopAtkInc", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket-TopAtkIncHvy", stat: "Rocket-TopAtkIncHvy", weight: WEIGHT.HEAVY }, // mra
			{ res: "R-Wpn-Rocket06-IDF", stat: "Rocket-IDF", weight: WEIGHT.ULTRAHEAVY }, // ripple
			{ res: "R-Wpn-MdArtMissile", stat: "Missile-MdArt", weight: WEIGHT.HEAVY }, // seraph
			{ res: "R-Wpn-Rocket-TopAtkPlas", stat: "Rocket-TopAtkPlas", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket-TopAtkPlasHvy", stat: "Rocket-TopAtkPlasHvy", weight: WEIGHT.HEAVY }, // mra
			{ res: "R-Wpn-HvArtMissile", stat: "Missile-HvyArt", weight: WEIGHT.ULTRAHEAVY }, // archie
			{ res: "R-Wpn-TBM-FuelAir", stat: "TBM-FuelAir", weight: WEIGHT.ULTRAHEAVY }, // harbringer tbm
			{ res: "R-Wpn-TBM-Earthquake", stat: "TBM-Earthquake", weight: WEIGHT.ULTRAHEAVY }, // hellshaker tbm
			{ res: "R-Wpn-TBM-Plasmite", stat: "TBM-Plasmite", weight: WEIGHT.ULTRAHEAVY }, // armageddon tbm
			{ res: "R-Wpn-TBM-Precision", stat: "TBM-Precision", weight: WEIGHT.ULTRAHEAVY }, // oblivion tbm
		],
		vtols: [
			{ res: "R-Wpn-Rocket02-MRL", stat: "Rocket-VTOL-MRL", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket-TopAttack", stat: "Rocket-VTOL-TopAttack", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket03-HvAT", stat: "Rocket-VTOL-BB", weight: WEIGHT.LIGHT }, // bb
			{ res: "R-Wpn-Rocket-BB2", stat: "Rocket-VTOL-BB2", weight: WEIGHT.MEDIUM }, // bb
			{ res: "R-Wpn-Rocket-TopAtkInc", stat: "Rocket-VTOL-TopAtkInc", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-MdArtMissile", stat: "Missile-VTOL-MdArt", weight: WEIGHT.LIGHT }, // mra
			{ res: "R-Wpn-Rocket-TopAtkPlasHvy", stat: "Rocket-VTOL-TopAtkPlasHvy", weight: WEIGHT.LIGHT }, // mra
		],
		defenses: [
			{ res: "R-Defense-Bunker-Rocket-MRL", stat: "Bunker-Rocket-MRL", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker-Rocket-MRLHvy", stat: "Bunker-Rocket-MRLHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker2-Rocket-TopAttack", stat: "Bunker2-Rocket-TopAttack", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker2-Rocket-TopAttackHvy", stat: "Bunker2-Rocket-TopAttackHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker2-Rocket-Ripple", stat: "Bunker2-Rocket-Ripple", defrole: DEFROLE.ARTY }, // ripple
			{ res: "R-Defense-Bunker2-Rocket-TopAtkInc", stat: "Bunker2-Rocket-TopAtkInc", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker2-Rocket-TopAtkIncHvy", stat: "Bunker2-Rocket-TopAtkIncHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker3-Rocket-Seraph", stat: "Bunker3-Rocket-Seraph", defrole: DEFROLE.STANDALONE }, // seraph
			{ res: "R-Defense-Bunker3-Rocket-SeraphHvy", stat: "Bunker3-Rocket-SeraphHvy", defrole: DEFROLE.STANDALONE }, // seraph
			{ res: "R-Defense-Bunker3-Rocket-TopAtkPlas", stat: "Bunker3-Rocket-TopAtkPlas", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker3-Rocket-TopAtkPlasHvy", stat: "Bunker3-Rocket-TopAtkPlasHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Bunker3-Rocket-Archangel", stat: "Bunker3-Rocket-Archangel", defrole: DEFROLE.ARTY }, // archie
			{ res: "R-Defense-Empl-Rocket-MRL", stat: "Emplacement-MRL-pit", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl-Rocket-MRLHvy", stat: "Empl-Rocket-MRLHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl2-Rocket-TopAttack", stat: "Empl2-Rocket-TopAttack", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl2-Rocket-TopAttackHvy", stat: "Empl2-Rocket-TopAttackHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl2-Rocket-Ripple", stat: "Emplacement-Rocket06-IDF", defrole: DEFROLE.ARTY }, // ripple
			{ res: "R-Defense-Empl2-Rocket-TopAtkInc", stat: "Empl2-Rocket-TopAtkInc", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl2-Rocket-TopAtkIncHvy", stat: "Empl2-Rocket-TopAtkIncHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl3-Rocket-Seraph", stat: "Emplacement-MdART-pit", defrole: DEFROLE.STANDALONE }, // seraph
			{ res: "R-Defense-Empl3-Rocket-SeraphHvy", stat: "Empl3-Rocket-SeraphHvy", defrole: DEFROLE.STANDALONE }, // seraph
			{ res: "R-Defense-Empl3-Rocket-TopAtkPlas", stat: "Empl3-Rocket-TopAtkPlas", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl3-Rocket-TopAtkPlasHvy", stat: "Empl3-Rocket-TopAtkPlasHvy", defrole: DEFROLE.STANDALONE }, // mra
			{ res: "R-Defense-Empl3-Rocket-Archangel", stat: "Emplacement-HvART-pit", defrole: DEFROLE.ARTY }, // archie
			{ res: "R-Defense-Empl3-TBM-FuelAir", stat: "Empl3-TBM-FuelAir", defrole: DEFROLE.ARTY }, // harbringer
			{ res: "R-Defense-Empl3-TBM-Earthquake", stat: "Empl3-TBM-Earthquake", defrole: DEFROLE.ARTY }, // hellshaker
			{ res: "R-Defense-Empl3-TBM-Plasmite", stat: "Empl3-TBM-Plasmite", defrole: DEFROLE.ARTY }, // armageddon
			{ res: "R-Defense-Empl3-TBM-Precision", stat: "Empl3-TBM-Precision", defrole: DEFROLE.ARTY }, // oblivion
		],
		templates: [
			{ res: "R-Wpn-Rocket02-MRL", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-MRL", ] }, // lancer borg
			{ res: "R-Wpn-Rocket-TopAttack", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-TopAttack", ] }, // lancer borg
			{ res: "R-Wpn-Rocket-TopAtkInc", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-TopAtkInc", ] }, // lancer borg
			{ res: "R-Wpn-MdArtMissile", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Missile-MdArt", ] }, // lancer borg
			{ res: "R-Wpn-Rocket-TopAtkPlasHvy", body: "CyborgHeavyBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Rocket-TopAtkPlas", ] }, // lancer borg
		],
		extras: [
			"R-Wpn-Cannon-Accuracy06",
			"R-Wpn-Cannon-ROF06",
			"R-Wpn-Cannon-Damage06",
			"R-Wpn-Flamer-ROF09",
			"R-Wpn-Flamer-Damage09",
			"R-Wpn-MG-Accuracy09",
			"R-Wpn-MG-Damage09",
			"R-Wpn-MG-ROF09",
			"R-Wpn-Bomb-Accuracy06",
			"R-Wpn-Energy-Accuracy06",
			"R-Wpn-Energy-Damage06",
			"R-Wpn-Energy-ROF06",
			"R-Wpn-Rail-Accuracy06",
			"R-Wpn-Rail-Damage06",
			"R-Wpn-Rail-ROF06",
			"R-Wpn-Artillery-Damage09",
			"R-Wpn-Artillery-ROF09",
			"R-Wpn-Artillery-Accuracy09",
			"R-Wpn-Missile-Damage03",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Missile-Accuracy03",
		],
	},
	rockets_AS: {
		roles: [ 0.0, 0.0, 1.0, 0.0 ],
		chatalias: "rxas",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-Rocket03-HvAT", stat: "Rocket-BB", weight: WEIGHT.MEDIUM }, // bb
			{ res: "R-Wpn-Rocket-BB2", stat: "Rocket-BB2", weight: WEIGHT.MEDIUM }, // bb
		],
		vtols: [
			{ res: "R-Wpn-Rocket03-HvAT", stat: "Rocket-VTOL-BB", weight: WEIGHT.LIGHT }, // bb
			{ res: "R-Wpn-Rocket-BB2", stat: "Rocket-VTOL-BB2", weight: WEIGHT.MEDIUM }, // bb
		],
		defenses: [],
		templates: [],
		extras: [],
	},
	rockets_AA: {
		roles: [ 0.0, 0.0, 0.0, 1.0 ],
		chatalias: "rxaa",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-Sunburst", stat: "Rocket-Sunburst", weight: WEIGHT.LIGHT }, // sunburst
			{ res: "R-Wpn-Missile-LtSAM", stat: "Missile-LtSAM", weight: WEIGHT.LIGHT }, // avenger
			{ res: "R-Wpn-Missile-HvSAM", stat: "Missile-HvySAM", weight: WEIGHT.HEAVY }, // vindicator
			{ res: "R-Wpn-Rocket-Cherub", stat: "Rocket-Cherub", weight: WEIGHT.HEAVY }, // cherub
			{ res: "R-Wpn-Missile-LtSAM2", stat: "Missile-LtSAM2", weight: WEIGHT.LIGHT }, // avenger
			{ res: "R-Wpn-Missile-HvSAM2", stat: "Missile-HvySAM2", weight: WEIGHT.HEAVY }, // vindicator
		],
		vtols: [
			{ res: "R-Wpn-Sunburst", stat: "Rocket-VTOL-Sunburst", weight: WEIGHT.LIGHT }, // sunburst a2a
			{ res: "R-Wpn-Rocket-Cherub", stat: "Rocket-VTOL-Cherub", weight: WEIGHT.LIGHT }, // cherub
		],
		defenses: [
			{ res: "R-Defense-Bunker-Rocket-Sunburst", stat: "P0-AASite-Sunburst", defrole: DEFROLE.STANDALONE }, // sunburst
			{ res: "R-Defense-Bunker2-Rocket-SAM", stat: "Bunker2-Rocket-SAM", defrole: DEFROLE.STANDALONE }, // avenger
			{ res: "R-Defense-Bunker2-Rocket-SAMHvy", stat: "Bunker2-Rocket-SAMHvy", defrole: DEFROLE.STANDALONE }, // vindicator
			{ res: "R-Defense-Bunker3-Rocket-Cherub", stat: "Bunker3-Rocket-Cherub", defrole: DEFROLE.STANDALONE }, // cherub
			{ res: "R-Defense-Bunker3-Rocket-SAM2", stat: "Bunker3-Rocket-SAM2", defrole: DEFROLE.STANDALONE }, // avenger
			{ res: "R-Defense-Bunker3-Rocket-SAM2Hvy", stat: "Bunker3-Rocket-SAM2Hvy", defrole: DEFROLE.STANDALONE }, // vindicator
			{ res: "R-Defense-Empl-Rocket-Sunburst", stat: "P0-AASite-Sunburst", defrole: DEFROLE.STANDALONE }, // sunburst
			{ res: "R-Defense-Empl2-Rocket-SAM", stat: "Empl2-Rocket-SAM", defrole: DEFROLE.STANDALONE }, // avenger
			{ res: "R-Defense-Empl2-Rocket-SAMHvy", stat: "Empl2-Rocket-SAMHvy", defrole: DEFROLE.STANDALONE }, // vindicator
			{ res: "R-Defense-Empl3-Rocket-Cherub", stat: "Empl3-Rocket-Cherub", defrole: DEFROLE.STANDALONE }, // cherub
			{ res: "R-Defense-Empl3-Rocket-SAM2", stat: "P0-AASite-SAM1", defrole: DEFROLE.STANDALONE }, // avenger
			{ res: "R-Defense-Empl3-Rocket-SAM2Hvy", stat: "P0-AASite-SAM2", defrole: DEFROLE.STANDALONE }, // vindicator
			{ res: "R-Defense-WallTower-Rocket-Sunburst", stat: "WallTower-Rocket-Sunburst", defrole: DEFROLE.STANDALONE }, // sunburst
			{ res: "R-Defense-WallTower2-Rocket-SAM", stat: "WallTower2-Rocket-SAM", defrole: DEFROLE.STANDALONE }, // avenger
			{ res: "R-Defense-WallTower2-Rocket-SAMHvy", stat: "WallTower2-Rocket-SAMHvy", defrole: DEFROLE.STANDALONE }, // vindicator
			{ res: "R-Defense-WallTower3-Rocket-Cherub", stat: "WallTower3-Rocket-Cherub", defrole: DEFROLE.STANDALONE }, // sunburst
			{ res: "R-Defense-WallTower3-Rocket-SAM2", stat: "WallTower-SamSite", defrole: DEFROLE.GATEWAY }, // avenger
			{ res: "R-Defense-WallTower3-Rocket-SAM2Hvy", stat: "WallTower-SamHvy", defrole: DEFROLE.GATEWAY }, // vindicator hardpoint
		],
		templates: [],
		extras: [],
	},
	lasers: {
		roles: [ 0.2, 0.6, 0.2, 0.0],
		chatalias: "ls",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Wpn-Laser-AP1", stat: "Laser-AP1", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AT1", stat: "Laser-AT1", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AP2", stat: "Laser-AP2", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Laser-AT2", stat: "Laser-AT2", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Laser-AP3", stat: "Laser-AP3", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AT3", stat: "Laser-AT3", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AP4", stat: "Laser-AP4", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Laser-AT4", stat: "Laser-AT4", weight: WEIGHT.HEAVY },
			{ res: "R-Wpn-Laser-Sonic", stat: "Laser-Sonic", weight: WEIGHT.ULTRAHEAVY },
		],
		vtols: [
			{ res: "R-Wpn-Laser-AP1", stat: "Laser-AP1-VTOL", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AT1", stat: "Laser-AT1-VTOL", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AP3", stat: "Laser-AP3-VTOL", weight: WEIGHT.LIGHT },
			{ res: "R-Wpn-Laser-AT3", stat: "Laser-AT3-VTOL", weight: WEIGHT.LIGHT },
		],
		defenses: [
			{ res: "R-Defense-Bunker2-Laser-AP1", stat: "Bunker2-Laser-AP1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker2-Laser-AT1", stat: "Bunker2-Laser-AT1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker2-Laser-AP2", stat: "Bunker2-Laser-AP2", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker2-Laser-AT2", stat: "Bunker2-Laser-AT2", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-Laser-AP3", stat: "Bunker3-Laser-AP3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-Laser-AT3", stat: "Bunker3-Laser-AT3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-Laser-AP4", stat: "Bunker3-Laser-AP4", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Bunker3-Laser-AT4", stat: "Bunker3-Laser-AT4", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Tower2-Laser-AP1", stat: "Bunker2-Laser-AP1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Tower2-Laser-AT1", stat: "Bunker2-Laser-AT1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Tower3-Laser-AP3", stat: "Bunker3-Laser-AP3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Tower3-Laser-AT3", stat: "Bunker3-Laser-AT3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower2-Laser-AP1", stat: "Bunker2-Laser-AP1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower2-Laser-AT1", stat: "Bunker2-Laser-AT1", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower2-Laser-AP2", stat: "Bunker2-Laser-AP2", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower2-Laser-AT2", stat: "Bunker2-Laser-AT2", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower3-Laser-AP3", stat: "Bunker3-Laser-AP3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower3-Laser-AT3", stat: "Bunker3-Laser-AT3", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower3-Laser-AP4", stat: "Bunker3-Laser-AP4", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower3-Laser-AT4", stat: "Bunker3-Laser-AT4", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Super-Laser", stat: "Super-Laser-Fort", defrole: DEFROLE.FORTRESS },
			{ res: "R-Defense-Super-Laser2", stat: "Super-Laser2-Fort", defrole: DEFROLE.FORTRESS },
		],
		templates: [
			{ res: "R-Wpn-Laser-AP1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Laser-AP1", ] }, // flash borg
			{ res: "R-Wpn-Laser-AP1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Laser-AP1", ] }, // flash borg
			{ res: "R-Wpn-Laser-AT1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Laser-AT1", ] }, // flash borg
			{ res: "R-Wpn-Laser-AT1", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Laser-AT1", ] }, // flash borg
			{ res: "R-Wpn-Laser-AP3", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Laser-AP3", ] }, // flash borg
			{ res: "R-Wpn-Laser-AP3", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Laser-AP3", ] }, // flash borg
			{ res: "R-Wpn-Laser-AT3", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-Laser-AT3", ] }, // flash borg
			{ res: "R-Wpn-Laser-AT3", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "HvyCyb-Wpn-Laser-AT3", ] }, // flash borg
		],
		extras: [],
	},
	spyturrets: {
		roles: [ 0.2, 0.6, 0.2, 0.0],
		chatalias: "spy",
		micro: MICRO.RANGED,
		weapons: [
			{ res: "R-Sys-SpyTurret", stat: "SpyTurret01", weight: WEIGHT.ULTRALIGHT }, // scrambler1
			{ res: "R-Sys-SpyTurret02", stat: "SpyTurret02", weight: WEIGHT.ULTRALIGHT }, // scrambler2
			{ res: "R-Sys-SpyTurret03", stat: "SpyTurret03", weight: WEIGHT.ULTRALIGHT }, // scrambler3
			{ res: "R-Sys-SpyTurretNEXUS", stat: "SpyTurretNEXUS", weight: WEIGHT.ULTRALIGHT }, // scrambler4
		],
		vtols: [],
		defenses: [
			{ res: "R-Defense-Bunker3-SpyTurretNEXUS", stat: "Bunker3-SpyTurretNEXUS", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-Tower3-SpyTurretNEXUS", stat: "Sys-SpyTower", defrole: DEFROLE.STANDALONE },
			{ res: "R-Defense-WallTower3-SpyTurretNEXUS", stat: "WallTower3-SpyTurretNEXUS", defrole: DEFROLE.GATEWAY },
			{ res: "R-Defense-Super-NEXUS", stat: "Super-NEXUS-Fort", defrole: DEFROLE.FORTRESS },
		],
		templates: [
			{ res: "R-Sys-SpyTurret", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-SpyTurret01", ] },
			{ res: "R-Sys-SpyTurret02", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-SpyTurret02", ] },
			{ res: "R-Sys-SpyTurret03", body: "CyborgLightBody", prop: "CyborgLegs", weapons: [ "Cyb-Wpn-SpyTurret03", ] },
		],
		extras: [],
	},
	useless_AT: {
		roles: [ 1.0, 0.0, 0.0, 0.0 ],
		chatalias: "useless_AT",
		weapons: [
			{ stat: "CannonSuper" }, // cannon fort weapon
			{ stat: "RocketSuper" }, // rocket bastion weapon
			{ stat: "MissileSuper" }, // missile fort weapon
			{ stat: "MassDriver" }, // mass driver fort weapon
			{ stat: "MortarEMP" }, // emp mortar
			{ stat: "EMP-Cannon" }, // emp cannon
		],
		vtols: [],
		defenses: [],
		templates: [],
		extras: [],
	},
	useless_AP: {
		roles: [ 0.0, 1.0, 0.0, 0.0 ],
		chatalias: "useless_AP",
		weapons: [
			{ stat: "MG1-Pillbox" }, // imaginary invisible single mg, may be found on some maps
			{ stat: "MG2-Pillbox" }, // imaginary invisible twin mg, may be found on some maps
			{ stat: "MG3-Pillbox" }, // mg bunker dedicated weapon
			{ stat: "NEXUSlink" }, // nexus link (still unused)
			{ stat: "MG4ROTARY-Pillbox" }, // ag bunker dedicated weapon
		],
		vtols: [],
		defenses: [],
		templates: [],
		extras: [],
	},
	useless_AS: {
		roles: [ 0.0, 0.0, 1.0, 0.0 ],
		chatalias: "useless_AS",
		weapons: [
			{ stat: "PlasmaHeavy" }, // plasma cannon (still unused)
		],
		vtols: [],
		defenses: [],
		templates: [],
		extras: [],
	},
	useless_AA: {
		roles: [ 0.0, 0.0, 0.0, 1.0 ],
		chatalias: "useless_AA",
		weapons: [
			{ stat: "QuadMg1AAGun" }, // hurricane (still unused)
			{ stat: "QuadRotAAGun" }, // whirlwind (still unused)
		],
		vtols: [],
		defenses: [],
		templates: [],
		extras: [],
	},
};
