// rules.init.baseType.js v0.1
//
// These settings will be applied to all players based on the game's base type setting
//
// Useful references:
// * https://warzone.atlassian.net/wiki/display/jsapi/Base+types
// * https://warzone.atlassian.net/wiki/display/mod/Player+Initialisation
//
// Processed by rules.init.js
//
// /////////////////////////////////////////////////////////////////



// /////////////////////////////////////////////////////////////////
// researchTechnologies list
//
// Varying numbers of these will be researched based on 'init.baseTypes' settings at bottom of file:

init.researchTechnologies = [
	"R-Vehicle-Prop-Wheels",
	"R-Sys-Spade1Mk1",
	"R-Vehicle-Body01",
	"R-Comp-SynapticLink",
	"R-Vehicle-Body04",
	"R-Wpn-MG1Mk1",
	"R-Defense-TankTrap01",
	"R-Defense-TankTrapGate",
	"R-Defense-TowerConst01",
	"R-Sys-Engineering01",
	"R-Vehicle-Prop-Halftracks",
	"R-Wpn-MG-Accuracy01",
	"R-Wpn-MG-Damage01",
	"R-Wpn-MG-ROF01",
	"R-Wpn-Cannon1Mk1",
	"R-Wpn-MG2Mk1",
	"R-Struc-RepairFacility",
	"R-Struc-PowerModuleMk1",
	"R-Wpn-MG3Mk1",
	"R-Wpn-Cannon-Accuracy01",
	"R-Wpn-Flamer01Mk1",
	"R-Wpn-Rocket05-MiniPod",
	"R-Wpn-Mortar01Lt",
	"R-Vehicle-Engine01",
	"R-Sys-Sensor-Turret01",
	"R-Sys-MobileRepairTurret01",
	"R-Comp-CommandTurret01",
	"R-Struc-CommandRelay",
	"R-Defense-EmplConst01",
	"R-Defense-HardcreteWall",
	"R-Defense-HardcreteGate",
	"R-Defense-TowerConst02",
	"R-Defense-BunkerConst01",
	"R-Defense-WallTowerConst01",
	"R-Struc-Research-Module",
	"R-Struc-Factory-Module",
	"R-Struc-Factory-Cyborg",
	"R-Cyborg-HvyConst",
	"R-Struc-Research-Upgrade01"
];


// /////////////////////////////////////////////////////////////////
// baseTypes definitions
//
// One of these per baseType. Defines what effects the baseType will have.
//
// Properties:
//   power:         Starting power
//   numTechs:      How many researchTechnologies to complete
//   normalKeep:    What structures do normal players keep
//   spectatorKeep: What structures do normal players keep
//   insaneKeep:    What structures do 'INSANE' AI players keep

init.baseTypes[CAMP_CLEAN] = {
	power: 1250,
	numTechs: 4,
	normalKeep:    [],
	spectatorKeep: [SAT_UPLINK],
	insaneKeep:    [DEFENSE,GATE,RESOURCE_EXTRACTOR,WALL]
}
init.baseTypes[CAMP_BASE] = {
	power: 1250,
	numTechs: 18,
	normalKeep: [FACTORY,HQ,LASSAT,POWER_GEN,REARM_PAD,REPAIR_FACILITY,RESEARCH_LAB,RESOURCE_EXTRACTOR,SAT_UPLINK,VTOL_FACTORY],
	spectatorKeep: [SAT_UPLINK],
	insaneKeep: [DEFENSE,FACTORY,HQ,LASSAT,POWER_GEN,REARM_PAD,REPAIR_FACILITY,RESEARCH_LAB,RESOURCE_EXTRACTOR,SAT_UPLINK,VTOL_FACTORY,WALL]
}
init.baseTypes[CAMP_WALLS] = {
	power: 1250,
	numTechs: init.researchTechnologies.length,
	normalKeep:    [COMMAND_CONTROL,CYBORG_FACTORY,DEFENSE,FACTORY,GATE,HQ,LASSAT,POWER_GEN,REARM_PAD,REPAIR_FACILITY,RESEARCH_LAB,RESOURCE_EXTRACTOR,SAT_UPLINK,VTOL_FACTORY,WALL],
	spectatorKeep: [SAT_UPLINK],
	insaneKeep:    [COMMAND_CONTROL,CYBORG_FACTORY,DEFENSE,FACTORY,GATE,HQ,LASSAT,POWER_GEN,REARM_PAD,REPAIR_FACILITY,RESEARCH_LAB,RESOURCE_EXTRACTOR,SAT_UPLINK,VTOL_FACTORY,WALL]
}
